@@ -1,16 +1,17 @@
 #! /usr/lib/veetest/veetest -r
-(revision "A.00.01")
-(date "Tue 17/Sep/1991")
-(component 0 "Context"
+(revision "B.00.00")
+(date "Fri 23/Oct/1992")
+(component 0 "ROOTCONTEXT"
  (name "HP VEE-Test: 3852A DAC Example")
  (interface
   (sequence in)
   (sequence out)
  )
  (implementation
-  (trigMode rad)
   (locked no)
-  (component 0 "Constant"
+  (trigMode rad)
+  (nextID 17)
+  (component 0 "CONSTANT"
    (name "NRDGS")
    (interface
     (sequence in)
@@ -29,6 +30,7 @@
     (component initializeAtPrerun off)
     (component initializeAtActivate off)
     (component initValue Int32
+     (name "LongInt")
      (datum 0)
     )
    )
@@ -37,13 +39,13 @@
      (extent 78 0)
     )
     (detail
-     (origin 14 224)
+     (origin 14 204)
      (extent 152 32)
     )
     (active detail)
    )
   )
-  (component 1 "LiteralConstant"
+  (component 1 "LITERALCONSTANT"
    (name "SPER")
    (interface
     (sequence in)
@@ -63,6 +65,7 @@
     (component initializeAtPrerun off)
     (component initializeAtActivate off)
     (component initValue Text
+     (name "CString")
      (datum "")
     )
    )
@@ -71,13 +74,13 @@
      (extent 46 0)
     )
     (detail
-     (origin 17 145)
+     (origin 17 125)
      (extent 146 30)
     )
     (active detail)
    )
   )
-  (component 2 "Constant"
+  (component 2 "CONSTANT"
    (name "# of blocks")
    (interface
     (sequence in)
@@ -96,6 +99,7 @@
     (component initializeAtPrerun off)
     (component initializeAtActivate off)
     (component initValue Int32
+     (name "LongInt")
      (datum 0)
     )
    )
@@ -104,13 +108,13 @@
      (extent 110 0)
     )
     (detail
-     (origin 15 306)
+     (origin 15 286)
      (extent 171 28)
     )
     (active detail)
    )
   )
-  (component 3 "Constant"
+  (component 3 "CONSTANT"
    (name "Block size")
    (subType "Integer")
    (interface
@@ -131,6 +135,7 @@
     (component initializeAtPrerun off)
     (component initializeAtActivate off)
     (component initValue Int32
+     (name "LongInt")
      (datum 0)
     )
    )
@@ -139,14 +144,14 @@
      (extent 110 0)
     )
     (detail
-     (origin 10 404)
+     (origin 10 384)
      (extent 180 33)
      (showFormat int)
     )
     (active detail)
    )
   )
-  (component 4 "Note"
+  (component 4 "NOTE"
    (name "Warranty Disclaimer")
    (interface
    )
@@ -165,19 +170,19 @@
      (extent 181 0)
     )
     (detail
-     (origin 719 122)
+     (origin 719 102)
      (extent 263 117)
      (editing enabled)
     )
     (active detail)
    )
   )
-  (component 5 "Gate"
+  (component 5 "GATE"
    (description 4 4
     The gate object will allow the current block of
-    readings to pass to the HP-UX Escape object when-
-    ever the top sequence in pin is pinged by the
-    If/Then object titled "A MOD 20 == 0".
+    readings to pass to the Execute Program object 
+    whenever the top sequence in pin is pinged by the
+    If/Then/Else object titled "A MOD 20 == 0".
    )
    (interface
     (sequence in)
@@ -198,7 +203,7 @@
    )
    (views
     (icon
-     (origin 727 288)
+     (origin 727 268)
      (extent 46 25)
     )
     (detail
@@ -207,7 +212,7 @@
     (active icon)
    )
   )
-  (component 6 "IODevice"
+  (component 6 "IODEVICE"
    (name "GPIO Data Transfer (GPIO@12)")
    (description 18 4
     Readings are read from the GPIO interface here.
@@ -256,9 +261,9 @@
    )
    (views
     (icon
-     (origin 409 328)
+     (origin 409 308)
      (extent 262 64)
-     (iconImage "/usr/lib/veetest/bitmaps/inst.icon")
+     (iconImage "inst.icon")
     )
     (detail
      (origin 318 603)
@@ -268,7 +273,7 @@
     (active icon)
    )
   )
-  (component 7 "ForCount"
+  (component 7 "FORCOUNT"
    (name "For Count")
    (interface
     (sequence in)
@@ -283,21 +288,19 @@
      )
      (lock constraints)
      (optional yes)
+     (buffer YES)
     )
     (output 1
      (type data)
      (lock name constraints)
     )
-    (buffers in
-     (buffer "Count")
-    )
    )
    (implementation
     (component count 500)
    )
    (views
     (icon
-     (origin 254 376)
+     (origin 254 356)
      (extent 112 69)
      (iconImage "loop.icon")
     )
@@ -308,7 +311,7 @@
     (active icon)
    )
   )
-  (component 8 "IODevice"
+  (component 8 "IODEVICE"
    (name "Trigger 3852A")
    (description 1 4
     The 44702A/B is triggered here.
@@ -325,9 +328,9 @@
    )
    (views
     (icon
-     (origin 247 288)
+     (origin 247 268)
      (extent 127 64)
-     (iconImage "/usr/lib/veetest/bitmaps/inst.icon")
+     (iconImage "inst.icon")
     )
     (detail
      (origin 229 352)
@@ -337,16 +340,17 @@
     (active icon)
    )
   )
-  (component 9 "Context"
+  (component 9 "CONTEXT"
    (name "Press For")
    (interface
     (sequence in)
     (sequence out)
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "IfThenElse"
+    (trigMode deg)
+    (nextID 3)
+    (component 0 "IFTHENELSE"
      (name "!= 0")
      (interface
       (sequence in)
@@ -384,7 +388,7 @@
       (active icon)
      )
     )
-    (component 1 "Toggle"
+    (component 1 "TOGGLE"
      (name "Info About")
      (interface
       (sequence in)
@@ -410,6 +414,7 @@
       (component initializeAtPrerun off)
       (component initializeAtActivate off)
       (component initValue Int32
+       (name "LongInt")
        (datum 0)
       )
      )
@@ -427,16 +432,17 @@
       (active icon)
      )
     )
-    (component 2 "Context"
+    (component 2 "CONTEXT"
      (name "Info About This Example")
      (interface
       (sequence in)
       (sequence out)
      )
      (implementation
-      (trigMode deg)
       (locked no)
-      (component 0 "Confirm"
+      (trigMode deg)
+      (nextID 2)
+      (component 0 "CONFIRM"
        (name "DONE")
        (description 7 8
         This tiny "thread" begins running when the 
@@ -471,12 +477,12 @@
         (active icon)
        )
       )
-      (component 1 "Note"
+      (component 1 "NOTE"
        (name "Explanation")
        (interface
        )
        (implementation
-        (component text 35 9
+        (component text 36 9
          This example shows a complete data acquisition solution that incorporates instrument control,
          data gathering, and data processing and report generation. The model in example "gpio1.ex"
          shows a usual data acquisition solution of instrument control and gathering where readings
@@ -488,21 +494,22 @@
          voltmeter within the 3852A, initiate the voltmeter's Data Buffer register prepatory to reading
          the GPIO interface, trigger the voltmeter, and read blocks of data from the GPIO interface, 
          respectively. More complete explanations can be found under the Show Description choice under 
-         the object menu for each of the above mentioned objects as well as the Gate and If/Then objects.
+         the object menu for each of the above mentioned objects as well as the Gate and If/Then/Else 
+         objects.
          
          Once a block of readings has been read by the Direct I/O object titled "GPIO Data Transfer"
-         the readings are output to file by using the To File object. By using the If/Then object titled
-         "A MOD 20 == 0"  and the Gate object every 20th block of readings is allowed to be unpacked by
-         a concurrent 'C' process managed by the HP-UX Escape object. Note that the READ transaction 
-         in the Direct I/O object and the WRITE transactions in the To File and HP-UX Escape objects 
-         use the Int32 datatype instead of an Int16 datatype. The readings returned by the 44702A/B
-         voltmeter via GPIO are in a 16-bit packed format, however the Int16 datatype, while apparently
-         well matched to the size of each packed reading, is not supported for purposes other than I/O
-         within VEE. This means any Int16 will be promoted to an Int32 upon output from an I/O object's
-         data output pin. This promotion incurs a slight overhead. It is more efficient to use the Int32 
-         datatype to read and write the packed readings, this avoids any promotions or demotions between 
-         Int16 and Int32 datatypes. Therefore when the block size is specified as 2048 this means 4096 
-         readings are being read from the GPIO interface by the Direct I/O object.
+         the readings are output to file by using the To File object. By using the If/Then/Else object 
+         titled "A MOD 20 == 0"  and the Gate object every 20th block of readings is allowed to be 
+         unpacked by a concurrent 'C' process managed by the Execute Program object. Note that the READ 
+         transaction in the Direct I/O object and the WRITE transactions in the To File and Execute 
+         Program objects use the Int32 datatype instead of an Int16 datatype. The readings returned by 
+         the 44702A/B voltmeter via GPIO are in a 16-bit packed format, however the Int16 datatype, while 
+         apparently well matched to the size of each packed reading, is not supported for purposes other 
+         than I/O within VEE. This means any Int16 will be promoted to an Int32 upon output from an I/O 
+         object's data output pin. This promotion incurs a slight overhead. It is more efficient to use 
+         the Int32 datatype to read and write the packed readings, this avoids any promotions or demotions 
+         between Int16 and Int32 datatypes. Therefore when the block size is specified as 2048 this means 
+         4096 readings are being read from the GPIO interface by the Direct I/O object.
          
          By allowing only every 20th block of 4096 readings to be unpacked and displayed, this model 
          is able to run efficiently enough to keep pace with the 44702A/B within the 3852A. In order
@@ -522,7 +529,7 @@
         (detail
          (origin 21 230)
          (extent 898 361)
-         (editing enabled)
+         (editing disabled)
         )
         (active detail)
        )
@@ -531,7 +538,7 @@
       )
       (ShowOnExecPanel
        (origin 29 92)
-       (extent 926 523)
+       (extent 926 513)
        (panel
         (origin 19 188)
         (extent 922 485)
@@ -559,6 +566,7 @@
        (extent 916 522)
        (configuration
        )
+       (stackingOrder 0 1)
       )
       (active icon)
      )
@@ -571,15 +579,15 @@
    )
    (views
     (icon
-     (origin 435 408)
+     (origin 375 668)
      (extent 110 25)
     )
     (panel
-     (origin 404 124)
+     (origin 404 104)
      (extent 293 73)
      (widget 1 icon
       (title off)
-      (origin 506 137)
+      (origin 506 117)
       (extent 114 39)
       (format button)
      )
@@ -607,21 +615,22 @@
        (Point 480 415)
       )
      )
+     (stackingOrder 0 1 2)
     )
     (active panel)
     (active panel)
    )
   )
-  (component 10 "IfThenElse"
+  (component 10 "IFTHENELSE"
    (name "A MOD 20 == 0")
    (description 7 4
-    This If/Then object's argument is true when ever
-    the current count output by the For Count object
-    is evenly divisible by 20. When this happens the
-    "then" data output pin is fired allowing the 
-    Gate object to pass the current block of readings
-    to the HP-UX object for unpacking and finally to
-    the Display object.
+    This If/Then/Else object's argument is true when 
+    ever the current count output by the For Count 
+    object is evenly divisible by 20. When this 
+    happens the "then" data output pin is fired 
+    allowing the Gate object to pass the current block 
+    of readings to the Execute Program object for 
+    unpacking and finally to the Display object.
    )
    (interface
     (sequence in)
@@ -648,7 +657,7 @@
    )
    (views
     (icon
-     (origin 537 258)
+     (origin 537 238)
      (extent 127 25)
     )
     (detail
@@ -659,7 +668,7 @@
     (active icon)
    )
   )
-  (component 11 "ToFile"
+  (component 11 "TOFILE"
    (name "To File")
    (interface
     (sequence in)
@@ -685,7 +694,7 @@
    )
    (views
     (icon
-     (origin 710 346)
+     (origin 710 326)
      (extent 80 29)
     )
     (detail
@@ -696,7 +705,7 @@
     (active icon)
    )
   )
-  (component 12 "YPlot"
+  (component 12 "YPLOT"
    (name "Voltage vs Time")
    (interface
     (sequence in)
@@ -720,7 +729,7 @@
      (iconImage "display.icon")
     )
     (detail
-     (origin 20 508)
+     (origin 20 488)
      (extent 960 224)
      (displayMode scrollGraph)
      (graphType cartesian)
@@ -743,7 +752,7 @@
     (active detail)
    )
   )
-  (component 13 "IODevice"
+  (component 13 "IODEVICE"
    (name "GPIO Data Transfer Setup")
    (description 10 4
     The IOCONTROL transactions are equivalent to the
@@ -771,9 +780,9 @@
    )
    (views
     (icon
-     (origin 197 208)
+     (origin 197 188)
      (extent 226 64)
-     (iconImage "/usr/lib/veetest/bitmaps/inst.icon")
+     (iconImage "inst.icon")
     )
     (detail
      (origin 134 197)
@@ -783,7 +792,7 @@
     (active icon)
    )
   )
-  (component 14 "IODevice"
+  (component 14 "IODEVICE"
    (name "3852A Setup")
    (description 7 4
     The series of commands here configure the 44702A/B
@@ -831,9 +840,9 @@
    )
    (views
     (icon
-     (origin 255 108)
+     (origin 255 88)
      (extent 110 64)
-     (iconImage "/usr/lib/veetest/bitmaps/inst.icon")
+     (iconImage "inst.icon")
     )
     (detail
      (origin 88 111)
@@ -843,21 +852,21 @@
     (active icon)
    )
   )
-  (component 15 "ShellEscape"
+  (component 15 "SHELLESCAPE"
    (description 27 4
-    The UP-UX Escape object manages the executable 
+    The Execute Program object manages the executable 
     "unpack.exe", the source for which is in the file 
     "unpack.c". This program unpacks a number of 
     packed 16 bit 44702A/B readings and returns them 
     as 64 bit reals. The number of readings to be 
     unpacked is input to the program as a command line 
-    argument. The HP-UX Escape writes the packed data
-    to the process via the process's stdin pipe and
-    reads the unpacked data from it's stdout pipe.
-    Since the program is written to run continuously,
-    reading and writing data from and to the HP-UX
-    Escape, the Wait for child exit choice on the 
-    object is set to "No".
+    argument. The Execute Program object writes the 
+    packed data to the process via the process's 
+    stdin pipe and reads the unpacked data from it's 
+    stdout pipe.  Since the program is written to run 
+    continuously, reading and writing data from and to 
+    the Execute Program object, the Wait for child 
+    exit choice on the object is set to "No".
     
     An important point is that UNIX pipes have a 
     default size of 8192 bytes. If more than this 
@@ -891,6 +900,7 @@
      )
      (lock constraints)
      (optional yes)
+     (buffer YES)
     )
     (input 3
      (type data)
@@ -908,9 +918,6 @@
      (lock constraints)
      (optional yes)
     )
-    (buffers in
-     (buffer "Command")
-    )
    )
    (implementation
     (attr iopath pipe read "pipe"
@@ -929,7 +936,7 @@
     )
     (procedure
       WRITE BINARY rawIn INT16
-      READ BINARY dataOut REAL COUNT:cnt
+      READ BINARY dataOut REAL64 COUNT:cnt
     )
     (component shell "none")
     (component command "/usr/lib/veetest/examples/3852A/unpack.exe 4096")
@@ -937,8 +944,8 @@
    )
    (views
     (icon
-     (origin 821 328)
-     (extent 118 64)
+     (origin 815 305)
+     (extent 151 71)
      (iconImage "c.icon")
     )
     (detail
@@ -949,7 +956,7 @@
     (active icon)
    )
   )
-  (component 16 "ToString"
+  (component 16 "TOSTRING"
    (interface
     (sequence in)
     (sequence out)
@@ -978,7 +985,7 @@
    )
    (views
     (icon
-     (origin 675 418)
+     (origin 675 398)
      (extent 110 25)
     )
     (detail
@@ -1011,128 +1018,128 @@
  )
  (views
   (detail
-   (origin 0 67)
-   (extent 995 668)
+   (origin 0 62)
+   (extent 983 650)
    (configuration
     (connect D10:1 D5:0
-     (Point 666 260)
-     (Point 750 260)
-     (Point 750 285)
+     (Point 666 240)
+     (Point 750 240)
+     (Point 750 265)
     )
     (connect D6:1 D5:1
-     (Point 673 360)
-     (Point 690 360)
-     (Point 690 300)
-     (Point 724 300)
+     (Point 673 340)
+     (Point 690 340)
+     (Point 690 280)
+     (Point 724 280)
     )
     (connect D7:1 D6:0
-     (Point 368 410)
-     (Point 390 410)
-     (Point 390 310)
-     (Point 540 310)
-     (Point 540 325)
+     (Point 368 390)
+     (Point 390 390)
+     (Point 390 290)
+     (Point 540 290)
+     (Point 540 305)
     )
     (connect D3:1 D6:1
-     (Point 192 420)
-     (Point 210 420)
-     (Point 210 460)
-     (Point 400 460)
-     (Point 400 360)
-     (Point 406 360)
+     (Point 192 400)
+     (Point 210 400)
+     (Point 210 440)
+     (Point 400 440)
+     (Point 400 340)
+     (Point 406 340)
     )
     (connect D8:0 D7:0
-     (Point 310 354)
-     (Point 310 373)
+     (Point 310 334)
+     (Point 310 353)
     )
     (connect D2:1 D7:1
-     (Point 188 320)
-     (Point 210 320)
-     (Point 210 410)
-     (Point 251 410)
+     (Point 188 300)
+     (Point 210 300)
+     (Point 210 390)
+     (Point 251 390)
     )
     (connect D13:0 D8:0
-     (Point 310 274)
-     (Point 310 285)
+     (Point 310 254)
+     (Point 310 265)
     )
     (connect D7:1 D10:1
-     (Point 368 410)
-     (Point 390 410)
-     (Point 390 310)
-     (Point 500 310)
-     (Point 500 270)
-     (Point 534 270)
+     (Point 368 390)
+     (Point 390 390)
+     (Point 390 290)
+     (Point 500 290)
+     (Point 500 250)
+     (Point 534 250)
     )
     (connect D6:1 D11:1
-     (Point 673 360)
-     (Point 707 360)
+     (Point 673 340)
+     (Point 707 340)
     )
     (connect D15:2 D12:1
-     (Point 941 380)
-     (Point 960 380)
-     (Point 960 410)
-     (Point 820 410)
-     (Point 820 470)
-     (Point 650 470)
-     (Point 650 460)
-     (Point 410 460)
-     (Point 410 470)
-     (Point 200 470)
-     (Point 200 460)
-     (Point 10 460)
-     (Point 10 620)
-     (Point 17 620)
+     (Point 968 360)
+     (Point 980 360)
+     (Point 980 390)
+     (Point 970 390)
+     (Point 970 440)
+     (Point 410 440)
+     (Point 410 450)
+     (Point 200 450)
+     (Point 200 440)
+     (Point 10 440)
+     (Point 10 600)
+     (Point 17 600)
     )
     (connect D14:0 D13:0
-     (Point 310 174)
-     (Point 310 205)
+     (Point 310 154)
+     (Point 310 185)
     )
     (connect D1:1 D14:1
-     (Point 165 160)
-     (Point 190 160)
-     (Point 190 120)
-     (Point 252 120)
+     (Point 165 140)
+     (Point 190 140)
+     (Point 190 100)
+     (Point 252 100)
     )
     (connect D0:1 D14:2
-     (Point 168 240)
-     (Point 180 240)
-     (Point 180 190)
-     (Point 200 190)
-     (Point 200 160)
-     (Point 252 160)
+     (Point 168 220)
+     (Point 180 220)
+     (Point 180 170)
+     (Point 200 170)
+     (Point 200 140)
+     (Point 252 140)
     )
     (connect D5:1 D15:1
-     (Point 775 300)
-     (Point 800 300)
-     (Point 800 340)
-     (Point 818 340)
+     (Point 775 280)
+     (Point 800 280)
+     (Point 800 320)
+     (Point 812 320)
     )
     (connect D16:1 D15:2
-     (Point 787 430)
-     (Point 800 430)
-     (Point 800 360)
-     (Point 818 360)
+     (Point 787 410)
+     (Point 800 410)
+     (Point 800 340)
+     (Point 812 340)
     )
     (connect D3:1 D15:3
-     (Point 192 420)
-     (Point 210 420)
-     (Point 210 460)
-     (Point 400 460)
-     (Point 400 430)
-     (Point 660 430)
-     (Point 660 460)
-     (Point 810 460)
-     (Point 810 380)
-     (Point 818 380)
+     (Point 192 400)
+     (Point 210 400)
+     (Point 210 440)
+     (Point 400 440)
+     (Point 400 410)
+     (Point 660 410)
+     (Point 660 380)
+     (Point 790 380)
+     (Point 790 360)
+     (Point 812 360)
     )
     (connect D3:1 D16:1
-     (Point 192 420)
-     (Point 210 420)
-     (Point 210 460)
-     (Point 400 460)
-     (Point 400 430)
-     (Point 672 430)
+     (Point 192 400)
+     (Point 210 400)
+     (Point 210 440)
+     (Point 400 440)
+     (Point 400 410)
+     (Point 672 410)
     )
    )
+   (stackingOrder 1 2 3 4 5 6 7 8 10 11
+     12 13 14 16 9 15 0)
   )
   (active detail)
   (numberFormats
