@@ -1,16 +1,17 @@
 #! /usr/lib/veetest/veetest -r
-(revision "A.00.01")
-(date "Tue 01/Oct/1991")
-(component 0 "Context"
+(revision "B.00.00")
+(date "Fri 23/Oct/1992")
+(component 0 "ROOTCONTEXT"
  (name "HP VEE-Test: 3852A DAC Example")
  (interface
   (sequence in)
   (sequence out)
  )
  (implementation
-  (trigMode deg)
   (locked no)
-  (component 0 "LiteralConstant"
+  (trigMode deg)
+  (nextID 18)
+  (component 0 "LITERALCONSTANT"
    (name "Buffer Size")
    (interface
     (sequence in)
@@ -29,6 +30,7 @@
     (component initializeAtPrerun off)
     (component initializeAtActivate off)
     (component initValue Text
+     (name "CString")
      (datum "")
     )
    )
@@ -38,13 +40,13 @@
      (extent 71 47)
     )
     (detail
-     (origin 11 123)
+     (origin 11 113)
      (extent 199 34)
     )
     (active detail)
    )
   )
-  (component 1 "Constant"
+  (component 1 "CONSTANT"
    (name "NRDGS")
    (interface
     (sequence in)
@@ -63,6 +65,7 @@
     (component initializeAtPrerun off)
     (component initializeAtActivate off)
     (component initValue Int32
+     (name "LongInt")
      (datum 0)
     )
    )
@@ -72,13 +75,13 @@
      (extent 35 47)
     )
     (detail
-     (origin 46 303)
+     (origin 46 293)
      (extent 129 34)
     )
     (active detail)
    )
   )
-  (component 2 "LiteralConstant"
+  (component 2 "LITERALCONSTANT"
    (name "SPER")
    (interface
     (sequence in)
@@ -97,6 +100,7 @@
     (component initializeAtPrerun off)
     (component initializeAtActivate off)
     (component initValue Text
+     (name "CString")
      (datum "")
     )
    )
@@ -106,13 +110,13 @@
      (extent 46 47)
     )
     (detail
-     (origin 11 213)
+     (origin 11 203)
      (extent 198 35)
     )
     (active detail)
    )
   )
-  (component 3 "Constant"
+  (component 3 "CONSTANT"
    (name "Transfer block size.")
    (interface
     (sequence in)
@@ -131,6 +135,7 @@
     (component initializeAtPrerun off)
     (component initializeAtActivate off)
     (component initValue Int32
+     (name "LongInt")
      (datum 0)
     )
    )
@@ -140,22 +145,22 @@
      (extent 152 47)
     )
     (detail
-     (origin 48 396)
+     (origin 48 386)
      (extent 264 48)
     )
     (active detail)
    )
   )
-  (component 4 "IfThenElse"
+  (component 4 "IFTHENELSE"
    (name "A MOD 20 == 0")
    (description 7 4
-    This If/Then object's argument is true when ever
-    the current count output by the For Count object
-    is evenly divisible by 20. When this happens the
-    "then" data output pin is fired allowing the 
-    Gate object to pass the current block of readings
-    to the HP-UX object for unpacking and finally to
-    the Display object.
+    This If/Then/Else object's argument is true when 
+    ever the current count output by the For Count 
+    object is evenly divisible by 20. When this 
+    happens the "then" data output pin is fired 
+    allowing the Gate object to pass the current block 
+    of readings to the Execute Program object for 
+    unpacking and finally to the Display object.
    )
    (interface
     (sequence in)
@@ -182,7 +187,7 @@
    )
    (views
     (icon
-     (origin 487 278)
+     (origin 487 268)
      (extent 127 25)
     )
     (detail
@@ -193,12 +198,12 @@
     (active icon)
    )
   )
-  (component 5 "Gate"
+  (component 5 "GATE"
    (description 4 4
     The gate object will allow the current block of
-    readings to pass to the HP-UX Escape object when-
-    ever the top sequence in pin is pinged by the
-    If/Then object titled "A MOD 20 == 0".
+    readings to pass to the Execute Program object 
+    whenever the top sequence in pin is pinged by the
+    If/Then/Else object titled "A MOD 20 == 0".
    )
    (interface
     (sequence in)
@@ -219,7 +224,7 @@
    )
    (views
     (icon
-     (origin 627 318)
+     (origin 627 308)
      (extent 46 25)
     )
     (detail
@@ -228,7 +233,7 @@
     (active icon)
    )
   )
-  (component 6 "Counter"
+  (component 6 "COUNTER"
    (interface
     (sequence in)
     (sequence out)
@@ -255,7 +260,7 @@
    )
    (views
     (icon
-     (origin 720 306)
+     (origin 720 296)
      (extent 80 29)
     )
     (detail
@@ -265,7 +270,7 @@
     (active icon)
    )
   )
-  (component 7 "Note"
+  (component 7 "NOTE"
    (name " Disclaimer")
    (interface
    )
@@ -288,14 +293,14 @@
      (extent 110 25)
     )
     (detail
-     (origin 801 115)
+     (origin 801 105)
      (extent 179 170)
      (editing enabled)
     )
     (active detail)
    )
   )
-  (component 8 "IfThenElse"
+  (component 8 "IFTHENELSE"
    (name "A == 5")
    (interface
     (sequence in)
@@ -322,7 +327,7 @@
    )
    (views
     (icon
-     (origin 881 437)
+     (origin 871 297)
      (extent 78 26)
     )
     (detail
@@ -333,7 +338,7 @@
     (active icon)
    )
   )
-  (component 9 "IODevice"
+  (component 9 "IODEVICE"
    (name "Trigger 3852A")
    (description 3 4
     This Direct I/O object contains the command line
@@ -352,9 +357,9 @@
    )
    (views
     (icon
-     (origin 307 178)
+     (origin 307 168)
      (extent 127 64)
-     (iconImage "/usr/lib/veetest/bitmaps/inst.icon")
+     (iconImage "inst.icon")
     )
     (detail
      (origin 146 287)
@@ -364,7 +369,7 @@
     (active icon)
    )
   )
-  (component 10 "ForCount"
+  (component 10 "FORCOUNT"
    (name "For Count")
    (interface
     (sequence in)
@@ -379,9 +384,9 @@
    )
    (views
     (icon
-     (origin 315 258)
+     (origin 315 248)
      (extent 110 64)
-     (iconImage "/usr/lib/veetest/bitmaps/loop.icon")
+     (iconImage "loop.icon")
     )
     (detail
      (origin 328 372)
@@ -390,16 +395,17 @@
     (active icon)
    )
   )
-  (component 11 "Context"
+  (component 11 "CONTEXT"
    (name "Press For")
    (interface
     (sequence in)
     (sequence out)
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "IfThenElse"
+    (trigMode deg)
+    (nextID 3)
+    (component 0 "IFTHENELSE"
      (name "!= 0")
      (interface
       (sequence in)
@@ -437,7 +443,7 @@
       (active icon)
      )
     )
-    (component 1 "Toggle"
+    (component 1 "TOGGLE"
      (name "Info About")
      (interface
       (sequence in)
@@ -463,6 +469,7 @@
       (component initializeAtPrerun off)
       (component initializeAtActivate off)
       (component initValue Int32
+       (name "LongInt")
        (datum 0)
       )
      )
@@ -480,16 +487,17 @@
       (active icon)
      )
     )
-    (component 2 "Context"
+    (component 2 "CONTEXT"
      (name "Info About This Example")
      (interface
       (sequence in)
       (sequence out)
      )
      (implementation
-      (trigMode deg)
       (locked no)
-      (component 0 "Confirm"
+      (trigMode deg)
+      (nextID 2)
+      (component 0 "CONFIRM"
        (name "DONE")
        (description 7 8
         This tiny "thread" begins running when the 
@@ -524,7 +532,7 @@
         (active icon)
        )
       )
-      (component 1 "Note"
+      (component 1 "NOTE"
        (name "Explanation")
        (interface
        )
@@ -536,8 +544,8 @@
          the data is transferred via the HP-IB interface instead of using GPIO.
          
          The Direct I/O objects titled "3852A Setup", "Trigger 3852A", and "HP-IB Data Transfer"
-         all have explanations in the Show Description choice under their object menus. The If/Then
-         object titled "A MOD 20 == 0", the Gate,  and the HP-UX Escape object also have explanations 
+         all have explanations in the Show Description choice under their object menus. The If/Then/Else
+         object titled "A MOD 20 == 0", the Gate,  and the Execute Program object also have explanations 
          under the Show Description choice.
          
          As in the examples "gpio1.ex" and "gpio2.ex", the efficiency of the model determines it's 
@@ -556,8 +564,8 @@
          In this way each block is displayed as a separate curve on the plot. This is done by using 
          the "Next Curve" control pin on the Display object. After five curves have been displayed the
          plot is cleared for the next five blocks of readings to be displayed. The clearing of the
-         display is controlled by the Counter and the If/Then object titled "A == 5". For more infor-
-         mation on data acquisition and HP VEE-Test please see the application note 1206-01 titled
+         display is controlled by the Counter and the If/Then/Else object titled "A == 5". For more 
+         information on data acquisition and HP VEE-Test please see the application note 1206-01 titled
          "Complete data Acquisition Solutions with HP VEE-Test".
          
            
@@ -572,7 +580,7 @@
         (detail
          (origin 21 230)
          (extent 898 361)
-         (editing enabled)
+         (editing disabled)
         )
         (active detail)
        )
@@ -609,6 +617,7 @@
        (extent 916 522)
        (configuration
        )
+       (stackingOrder 0 1)
       )
       (active icon)
      )
@@ -621,15 +630,15 @@
    )
    (views
     (icon
-     (origin 435 408)
+     (origin 305 648)
      (extent 110 25)
     )
     (panel
-     (origin 475 147)
+     (origin 475 137)
      (extent 290 67)
      (widget 1 icon
       (title off)
-      (origin 577 160)
+      (origin 577 150)
       (extent 114 39)
       (format button)
      )
@@ -657,12 +666,13 @@
        (Point 480 415)
       )
      )
+     (stackingOrder 0 1 2)
     )
     (active panel)
     (active panel)
    )
   )
-  (component 12 "YPlot"
+  (component 12 "YPLOT"
    (name "XY Trace")
    (subType "XY_Trace")
    (interface
@@ -703,7 +713,7 @@
      (iconImage "display.icon")
     )
     (detail
-     (origin 225 550)
+     (origin 225 540)
      (extent 710 180)
      (displayMode graphOnly)
      (graphType cartesian)
@@ -727,7 +737,7 @@
     (active detail)
    )
   )
-  (component 13 "IODevice"
+  (component 13 "IODEVICE"
    (name "HP-IB Data Transfer")
    (description 17 4
     This direct I/O object contains the transaction
@@ -771,7 +781,7 @@
    )
    (views
     (icon
-     (origin 370 348)
+     (origin 370 338)
      (extent 181 64)
      (iconImage "io.icon")
     )
@@ -783,7 +793,7 @@
     (active icon)
    )
   )
-  (component 14 "ToFile"
+  (component 14 "TOFILE"
    (interface
     (sequence in)
     (sequence out)
@@ -807,7 +817,7 @@
    )
    (views
     (icon
-     (origin 601 368)
+     (origin 601 358)
      (extent 78 25)
     )
     (detail
@@ -818,7 +828,7 @@
     (active icon)
    )
   )
-  (component 15 "ToString"
+  (component 15 "TOSTRING"
    (interface
     (sequence in)
     (sequence out)
@@ -847,7 +857,7 @@
    )
    (views
     (icon
-     (origin 575 408)
+     (origin 575 398)
      (extent 110 25)
     )
     (detail
@@ -858,21 +868,21 @@
     (active icon)
    )
   )
-  (component 16 "ShellEscape"
+  (component 16 "SHELLESCAPE"
    (description 27 4
-    The UP-UX Escape object manages the executable 
+    The Execute Program object manages the executable 
     "unpack.exe", the source for which is in the file 
     "unpack.c". This program unpacks a number of 
     packed 16 bit 44702A/B readings and returns them 
     as 64 bit reals. The number of readings to be 
     unpacked is input to the program as a command line 
-    argument. The HP-UX Escape writes the packed data
-    to the process via the process's stdin pipe and
-    reads the unpacked data from it's stdout pipe.
-    Since the program is written to run continuously,
-    reading and writing data from and to the HP-UX
-    Escape, the Wait for child exit choice on the 
-    object is set to "No".
+    argument. The Execute Program object writes the 
+    packed data to the process via the process's 
+    stdin pipe and reads the unpacked data from it's 
+    stdout pipe.  Since the program is written to run 
+    continuously, reading and writing data from and 
+    to the Execute Program object, the Wait for child 
+    exit choice on the object is set to "No".
     
     An important point is that UNIX pipes have a 
     default size of 8192 bytes. If more than this 
@@ -906,6 +916,7 @@
      )
      (lock constraints)
      (optional yes)
+     (buffer YES)
     )
     (input 3
      (type data)
@@ -923,9 +934,6 @@
      (lock constraints)
      (optional yes)
     )
-    (buffers in
-     (buffer "Command")
-    )
    )
    (implementation
     (attr iopath pipe read "pipe"
@@ -944,7 +952,7 @@
     )
     (procedure
       WRITE BINARY rawIn INT32
-      READ BINARY dataOut REAL COUNT:cnt*2
+      READ BINARY dataOut REAL64 COUNT:cnt*2
     )
     (component shell "none")
     (component command "/usr/lib/veetest/examples/3852A/unpack.exe 1024")
@@ -952,8 +960,8 @@
    )
    (views
     (icon
-     (origin 721 358)
-     (extent 118 64)
+     (origin 744 346)
+     (extent 152 68)
      (iconImage "c.icon")
     )
     (detail
@@ -964,7 +972,7 @@
     (active icon)
    )
   )
-  (component 17 "IODevice"
+  (component 17 "IODEVICE"
    (name "3852A Setup")
    (description 18 4
     This Direct I/O object contains two downloadable
@@ -1056,9 +1064,9 @@
    )
    (views
     (icon
-     (origin 315 88)
+     (origin 315 78)
      (extent 110 64)
-     (iconImage "/usr/lib/veetest/bitmaps/inst.icon")
+     (iconImage "inst.icon")
     )
     (detail
      (origin 127 111)
@@ -1097,173 +1105,169 @@
  )
  (views
   (detail
-   (origin 0 67)
-   (extent 1248 902)
+   (origin 0 62)
+   (extent 979 668)
    (configuration
     (connect D10:1 D4:1
-     (Point 427 290)
-     (Point 484 290)
+     (Point 427 280)
+     (Point 484 280)
     )
     (connect D4:1 D5:0
-     (Point 616 280)
-     (Point 650 280)
-     (Point 650 315)
+     (Point 616 270)
+     (Point 650 270)
+     (Point 650 305)
     )
     (connect D13:1 D5:1
-     (Point 553 380)
-     (Point 580 380)
-     (Point 580 330)
-     (Point 624 330)
+     (Point 553 370)
+     (Point 580 370)
+     (Point 580 320)
+     (Point 624 320)
     )
     (connect D4:1 D6:1
-     (Point 616 280)
-     (Point 650 280)
-     (Point 650 300)
+     (Point 616 270)
+     (Point 650 270)
+     (Point 650 290)
+     (Point 690 290)
      (Point 690 300)
-     (Point 690 310)
-     (Point 717 310)
+     (Point 717 300)
     )
     (connect D8:1 D6:2
-     (Point 961 440)
-     (Point 980 440)
-     (Point 980 480)
-     (Point 850 480)
-     (Point 850 350)
-     (Point 710 350)
-     (Point 710 330)
-     (Point 717 330)
+     (Point 951 300)
+     (Point 970 300)
+     (Point 970 340)
+     (Point 900 340)
+     (Point 900 330)
+     (Point 810 330)
+     (Point 810 340)
+     (Point 710 340)
+     (Point 710 320)
+     (Point 717 320)
     )
     (connect D6:1 D8:1
-     (Point 802 320)
-     (Point 860 320)
-     (Point 860 450)
-     (Point 878 450)
+     (Point 802 310)
+     (Point 868 310)
     )
     (connect D17:0 D9:0
-     (Point 370 154)
-     (Point 370 164)
-     (Point 370 164)
-     (Point 370 175)
+     (Point 370 144)
+     (Point 370 165)
     )
     (connect D9:0 D10:0
-     (Point 370 244)
-     (Point 370 255)
+     (Point 370 234)
+     (Point 370 245)
     )
     (connect D16:2 D12:1
-     (Point 841 410)
-     (Point 990 410)
-     (Point 990 490)
-     (Point 100 490)
-     (Point 100 580)
-     (Point 112 580)
+     (Point 898 400)
+     (Point 920 400)
+     (Point 920 480)
+     (Point 100 480)
+     (Point 100 570)
+     (Point 112 570)
     )
     (connect D5:1 D12:2
-     (Point 675 330)
-     (Point 700 330)
-     (Point 700 380)
-     (Point 730 380)
-     (Point 730 470)
-     (Point 90 470)
-     (Point 90 620)
-     (Point 112 620)
+     (Point 675 320)
+     (Point 700 320)
+     (Point 700 360)
+     (Point 720 360)
+     (Point 720 460)
+     (Point 90 460)
+     (Point 90 610)
+     (Point 112 610)
     )
     (connect D8:1 D12:3
-     (Point 961 440)
-     (Point 980 440)
-     (Point 980 480)
-     (Point 850 480)
-     (Point 850 460)
-     (Point 80 460)
-     (Point 80 470)
-     (Point 70 470)
-     (Point 70 660)
-     (Point 112 660)
+     (Point 951 300)
+     (Point 970 300)
+     (Point 970 340)
+     (Point 930 340)
+     (Point 930 490)
+     (Point 70 490)
+     (Point 70 650)
+     (Point 112 650)
     )
     (connect D16:0 D12:4
-     (Point 780 424)
-     (Point 780 480)
-     (Point 80 480)
-     (Point 80 700)
-     (Point 112 700)
+     (Point 820 416)
+     (Point 820 470)
+     (Point 80 470)
+     (Point 80 690)
+     (Point 112 690)
     )
     (connect D10:1 D13:0
-     (Point 427 290)
-     (Point 460 290)
-     (Point 460 345)
+     (Point 427 280)
+     (Point 460 280)
+     (Point 460 335)
     )
     (connect D3:1 D13:1
-     (Point 314 420)
-     (Point 330 420)
-     (Point 330 380)
-     (Point 367 380)
+     (Point 314 410)
+     (Point 330 410)
+     (Point 330 370)
+     (Point 367 370)
     )
     (connect D13:1 D14:1
-     (Point 553 380)
-     (Point 575 380)
-     (Point 575 380)
-     (Point 598 380)
+     (Point 553 370)
+     (Point 598 370)
     )
     (connect D3:1 D15:1
-     (Point 314 420)
+     (Point 314 410)
+     (Point 330 410)
      (Point 330 420)
-     (Point 330 430)
-     (Point 560 430)
      (Point 560 420)
-     (Point 572 420)
+     (Point 560 410)
+     (Point 572 410)
     )
     (connect D5:1 D16:1
-     (Point 675 330)
-     (Point 700 330)
-     (Point 700 370)
-     (Point 718 370)
+     (Point 675 320)
+     (Point 700 320)
+     (Point 700 360)
+     (Point 741 360)
     )
     (connect D15:1 D16:2
-     (Point 687 420)
-     (Point 700 420)
-     (Point 700 390)
-     (Point 718 390)
+     (Point 687 410)
+     (Point 700 410)
+     (Point 700 380)
+     (Point 741 380)
     )
     (connect D3:1 D16:3
-     (Point 314 420)
+     (Point 314 410)
+     (Point 330 410)
      (Point 330 420)
-     (Point 330 430)
-     (Point 560 430)
-     (Point 560 450)
-     (Point 710 450)
-     (Point 710 410)
-     (Point 718 410)
+     (Point 560 420)
+     (Point 560 440)
+     (Point 710 440)
+     (Point 710 400)
+     (Point 741 400)
     )
     (connect D0:1 D17:1
-     (Point 212 140)
-     (Point 230 140)
-     (Point 230 100)
-     (Point 312 100)
+     (Point 212 130)
+     (Point 230 130)
+     (Point 230 90)
+     (Point 312 90)
     )
     (connect D2:1 D17:2
-     (Point 211 230)
-     (Point 240 230)
-     (Point 240 110)
-     (Point 312 110)
+     (Point 211 220)
+     (Point 240 220)
+     (Point 240 100)
+     (Point 312 100)
     )
     (connect D1:1 D17:3
-     (Point 177 320)
-     (Point 250 320)
+     (Point 177 310)
+     (Point 250 310)
+     (Point 250 110)
+     (Point 312 110)
+    )
+    (connect D1:1 D17:4
+     (Point 177 310)
+     (Point 250 310)
      (Point 250 120)
      (Point 312 120)
     )
-    (connect D1:1 D17:4
-     (Point 177 320)
-     (Point 250 320)
+    (connect D1:1 D17:5
+     (Point 177 310)
+     (Point 250 310)
      (Point 250 130)
      (Point 312 130)
     )
-    (connect D1:1 D17:5
-     (Point 177 320)
-     (Point 250 320)
-     (Point 250 140)
-     (Point 312 140)
-    )
    )
+   (stackingOrder 0 1 2 3 4 5 6 7 9 10
+     13 14 15 17 11 16 8 12)
   )
   (active detail)
   (numberFormats
