@@ -1,14 +1,15 @@
 #! /usr/lib/veetest/veetest -r
-(revision "A.00.01")
-(date "Thu 19/Sep/1991")
-(component 0 "Context"
+(revision "B.00.00")
+(date "Fri 23/Oct/1992")
+(component 0 "ROOTCONTEXT"
  (name "Number Base Conversion")
  (interface
  )
  (implementation
-  (trigMode deg)
   (locked no)
-  (component 0 "Junction"
+  (trigMode deg)
+  (nextID 13)
+  (component 0 "JUNCTION"
    (name "JCT")
    (interface
     (input 1
@@ -41,7 +42,7 @@
    )
    (views
     (icon
-     (origin 587 388)
+     (origin 617 388)
      (extent 46 45)
     )
     (detail
@@ -50,7 +51,7 @@
     (active icon)
    )
   )
-  (component 1 "TextDisplay"
+  (component 1 "TEXTDISPLAY"
    (name "Decimal")
    (interface
     (sequence in)
@@ -69,13 +70,13 @@
      (extent 78 0)
     )
     (detail
-     (origin 695 253)
+     (origin 705 248)
      (extent 190 35)
     )
     (active detail)
    )
   )
-  (component 2 "TextDisplay"
+  (component 2 "TEXTDISPLAY"
    (name "Hexadecimal")
    (interface
     (sequence in)
@@ -95,7 +96,7 @@
      (extent 110 25)
     )
     (detail
-     (origin 695 353)
+     (origin 705 348)
      (extent 210 35)
      (formatter
       (realFormat standard)
@@ -107,7 +108,7 @@
     (active detail)
    )
   )
-  (component 3 "TextDisplay"
+  (component 3 "TEXTDISPLAY"
    (name "Octal")
    (interface
     (sequence in)
@@ -127,7 +128,7 @@
      (extent 78 25)
     )
     (detail
-     (origin 695 453)
+     (origin 705 448)
      (extent 210 35)
      (formatter
       (realFormat standard)
@@ -139,7 +140,7 @@
     (active detail)
    )
   )
-  (component 4 "TextDisplay"
+  (component 4 "TEXTDISPLAY"
    (name "Binary")
    (interface
     (sequence in)
@@ -159,7 +160,7 @@
      (extent 78 25)
     )
     (detail
-     (origin 705 563)
+     (origin 715 558)
      (extent 210 35)
      (formatter
       (realFormat standard)
@@ -171,7 +172,7 @@
     (active detail)
    )
   )
-  (component 5 "IfThenElse"
+  (component 5 "IFTHENELSE"
    (interface
     (sequence in)
     (sequence out)
@@ -209,8 +210,8 @@
    )
    (views
     (icon
-     (origin 261 388)
-     (extent 78 45)
+     (origin 256 378)
+     (extent 129 45)
     )
     (detail
      (origin 256 418)
@@ -220,7 +221,7 @@
     (active icon)
    )
   )
-  (component 6 "EnumConstant"
+  (component 6 "ENUMCONSTANT"
    (name "convert from")
    (interface
     (sequence in)
@@ -240,12 +241,13 @@
       ( "HEX" 2)
       ( "OCTAL" 3)
      )
-     (datum "HEX")
+     (datum "DECIMAL")
     )
     (component autoTrigger on)
     (component initializeAtPrerun off)
     (component initializeAtActivate off)
     (component initValue Enum
+     (name "Enum")
      (shared yes)
      (datum "DECIMAL")
     )
@@ -255,14 +257,14 @@
      (extent 118 0)
     )
     (detail
-     (origin 24 358)
+     (origin 34 353)
      (extent 192 104)
      (format buttons)
     )
     (active detail)
    )
   )
-  (component 7 "Context"
+  (component 7 "CONTEXT"
    (name "HEXADECIMAL")
    (interface
     (sequence in)
@@ -280,9 +282,10 @@
     )
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "Confirm"
+    (trigMode deg)
+    (nextID 2)
+    (component 0 "CONFIRM"
      (interface
       (sequence in)
       (sequence out)
@@ -305,7 +308,7 @@
       (active icon)
      )
     )
-    (component 1 "Slider"
+    (component 1 "SLIDER"
      (name "HEXADECIMAL")
      (subType "Integer_Slid")
      (interface
@@ -321,12 +324,13 @@
       (component value Int32
        (name "HEXADECIMAL")
        (values range 0 100)
-       (datum 60)
+       (datum 67)
       )
       (component autoTrigger off)
       (component initializeAtPrerun off)
       (component initializeAtActivate off)
       (component initValue Int32
+       (name "LongInt")
        (datum 0)
       )
       (component detents 1)
@@ -356,7 +360,7 @@
     )
     (ShowOnExecPanel
      (origin 336 73)
-     (extent 239 335)
+     (extent 239 325)
      (panel
       (origin 273 352)
       (extent 235 297)
@@ -381,7 +385,7 @@
    )
    (views
     (icon
-     (origin 405 428)
+     (origin 455 418)
      (extent 110 25)
     )
     (detail
@@ -394,18 +398,19 @@
       )
       (connect D0:1 D1:0
        (Point 673 440)
-       (Point 570 133)
+       (Point 570 135)
       )
       (connect D1:1 O1:1
        (Point 677 280)
        (Point 701 320)
       )
      )
+     (stackingOrder 0 1)
     )
     (active icon)
    )
   )
-  (component 8 "Context"
+  (component 8 "CONTEXT"
    (name "OCTAL")
    (interface
     (sequence in)
@@ -423,9 +428,10 @@
     )
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "Confirm"
+    (trigMode deg)
+    (nextID 2)
+    (component 0 "CONFIRM"
      (interface
       (sequence in)
       (sequence out)
@@ -448,7 +454,7 @@
       (active icon)
      )
     )
-    (component 1 "Slider"
+    (component 1 "SLIDER"
      (name "OCTAL")
      (subType "Integer_Slid")
      (interface
@@ -464,12 +470,13 @@
       (component value Int32
        (name "OCTAL")
        (values range 0 100)
-       (datum 78)
+       (datum 36)
       )
       (component autoTrigger off)
       (component initializeAtPrerun off)
       (component initializeAtActivate off)
       (component initValue Int32
+       (name "LongInt")
        (datum 0)
       )
       (component detents 1)
@@ -493,7 +500,7 @@
     )
     (ShowOnExecPanel
      (origin 328 75)
-     (extent 244 339)
+     (extent 244 329)
      (panel
       (origin 340 370)
       (extent 240 301)
@@ -518,7 +525,7 @@
    )
    (views
     (icon
-     (origin 421 478)
+     (origin 471 468)
      (extent 78 25)
     )
     (detail
@@ -531,18 +538,19 @@
       )
       (connect D0:1 D1:0
        (Point 628 560)
-       (Point 530 253)
+       (Point 530 255)
       )
       (connect D1:1 O1:1
        (Point 637 400)
        (Point 684 430)
       )
      )
+     (stackingOrder 0 1)
     )
     (active icon)
    )
   )
-  (component 9 "Context"
+  (component 9 "CONTEXT"
    (name "DECIMAL")
    (interface
     (sequence in)
@@ -560,9 +568,10 @@
     )
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "Slider"
+    (trigMode deg)
+    (nextID 2)
+    (component 0 "SLIDER"
      (name "DECIMAL")
      (subType "Integer_Slid")
      (interface
@@ -578,12 +587,13 @@
       (component value Int32
        (name "DECIMAL")
        (values range 0 100)
-       (datum 58)
+       (datum 77)
       )
       (component autoTrigger off)
       (component initializeAtPrerun off)
       (component initializeAtActivate off)
       (component initValue Int32
+       (name "LongInt")
        (datum 0)
       )
       (component detents 1)
@@ -600,7 +610,7 @@
       (active detail)
      )
     )
-    (component 1 "Confirm"
+    (component 1 "CONFIRM"
      (interface
       (sequence in)
       (sequence out)
@@ -630,7 +640,7 @@
     )
     (ShowOnExecPanel
      (origin 337 74)
-     (extent 234 346)
+     (extent 234 336)
      (panel
       (origin 355 246)
       (extent 230 308)
@@ -649,7 +659,7 @@
    )
    (views
     (icon
-     (origin 421 368)
+     (origin 461 358)
      (extent 78 25)
     )
     (detail
@@ -658,7 +668,7 @@
      (configuration
       (connect D1:1 D0:0
        (Point 448 160)
-       (Point 525 253)
+       (Point 525 255)
       )
       (connect I1:1 D1:0
        (Point 366 310)
@@ -669,11 +679,12 @@
        (Point 644 310)
       )
      )
+     (stackingOrder 0 1)
     )
     (active icon)
    )
   )
-  (component 10 "Context"
+  (component 10 "CONTEXT"
    (name "BINARY")
    (interface
     (sequence in)
@@ -691,9 +702,10 @@
     )
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "Confirm"
+    (trigMode deg)
+    (nextID 2)
+    (component 0 "CONFIRM"
      (interface
       (sequence in)
       (sequence out)
@@ -716,7 +728,7 @@
       (active icon)
      )
     )
-    (component 1 "Slider"
+    (component 1 "SLIDER"
      (name "BINARY")
      (subType "Integer_Slid")
      (interface
@@ -732,12 +744,13 @@
       (component value Int32
        (name "BINARY")
        (values range 0 100)
-       (datum 0)
+       (datum 54)
       )
       (component autoTrigger off)
       (component initializeAtPrerun off)
       (component initializeAtActivate off)
       (component initValue Int32
+       (name "LongInt")
        (datum 0)
       )
       (component detents 1)
@@ -767,7 +780,7 @@
     )
     (ShowOnExecPanel
      (origin 329 74)
-     (extent 246 335)
+     (extent 246 325)
      (panel
       (origin 339 142)
       (extent 242 297)
@@ -792,7 +805,7 @@
    )
    (views
     (icon
-     (origin 421 308)
+     (origin 461 298)
      (extent 78 25)
     )
     (detail
@@ -805,18 +818,19 @@
       )
       (connect D0:1 D1:0
        (Point 403 160)
-       (Point 480 253)
+       (Point 480 255)
       )
       (connect D1:1 O1:1
        (Point 587 400)
        (Point 599 310)
       )
      )
+     (stackingOrder 0 1)
     )
     (active icon)
    )
   )
-  (component 11 "Note"
+  (component 11 "NOTE"
    (name "Warranty Disclaimer")
    (interface
    )
@@ -833,23 +847,24 @@
      (extent 181 0)
     )
     (detail
-     (origin 352 119)
+     (origin 362 114)
      (extent 397 82)
      (editing disabled)
     )
     (active detail)
    )
   )
-  (component 12 "Context"
+  (component 12 "CONTEXT"
    (name "Press For")
    (interface
     (sequence in)
     (sequence out)
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "IfThenElse"
+    (trigMode deg)
+    (nextID 3)
+    (component 0 "IFTHENELSE"
      (name "!= 0")
      (interface
       (sequence in)
@@ -887,7 +902,7 @@
       (active icon)
      )
     )
-    (component 1 "Toggle"
+    (component 1 "TOGGLE"
      (name "Info About")
      (interface
       (sequence in)
@@ -913,6 +928,7 @@
       (component initializeAtPrerun off)
       (component initializeAtActivate off)
       (component initValue Int32
+       (name "LongInt")
        (datum 0)
       )
      )
@@ -930,16 +946,17 @@
       (active icon)
      )
     )
-    (component 2 "Context"
+    (component 2 "CONTEXT"
      (name "Info About This Example")
      (interface
       (sequence in)
       (sequence out)
      )
      (implementation
-      (trigMode deg)
       (locked no)
-      (component 0 "Confirm"
+      (trigMode deg)
+      (nextID 2)
+      (component 0 "CONFIRM"
        (name "DONE")
        (description 7 8
         This tiny "thread" begins running when the 
@@ -974,7 +991,7 @@
         (active icon)
        )
       )
-      (component 1 "Note"
+      (component 1 "NOTE"
        (name "NotePad")
        (description 2 8
         This notepad is displayed as a Show on Execute
@@ -1015,7 +1032,7 @@
       )
       (ShowOnExecPanel
        (origin 62 43)
-       (extent 849 374)
+       (extent 849 364)
        (panel
         (origin 28 352)
         (extent 845 336)
@@ -1043,6 +1060,7 @@
        (extent 866 520)
        (configuration
        )
+       (stackingOrder 0 1)
       )
       (active icon)
      )
@@ -1059,11 +1077,11 @@
      (extent 110 25)
     )
     (panel
-     (origin 11 122)
+     (origin 21 117)
      (extent 319 77)
      (widget 1 icon
       (title off)
-      (origin 113 135)
+      (origin 123 130)
       (extent 114 39)
       (format button)
      )
@@ -1089,6 +1107,7 @@
        (Point 450 505)
       )
      )
+     (stackingOrder 0 1 2)
     )
     (active panel)
     (active panel)
@@ -1112,16 +1131,16 @@
  )
  (views
   (panel
-   (origin 0 67)
+   (origin 0 62)
    (extent 984 363)
    (widget 1 detail
     (title on)
-    (origin 34 340)
+    (origin 34 335)
     (extent 190 35)
    )
    (widget 2 detail
     (title on)
-    (origin 249 342)
+    (origin 249 337)
     (extent 210 35)
     (formatter
      (realFormat standard)
@@ -1132,7 +1151,7 @@
    )
    (widget 3 detail
     (title on)
-    (origin 502 342)
+    (origin 502 337)
     (extent 210 35)
     (formatter
      (realFormat standard)
@@ -1143,7 +1162,7 @@
    )
    (widget 4 detail
     (title on)
-    (origin 756 343)
+    (origin 756 338)
     (extent 210 35)
     (formatter
      (realFormat standard)
@@ -1154,113 +1173,113 @@
    )
    (widget 11 detail
     (title on)
-    (origin 574 110)
+    (origin 574 105)
     (extent 397 82)
     (editing disabled)
    )
    (widget 12 panel
     (title on)
-    (origin 15 111)
+    (origin 15 106)
     (extent 319 77)
     (widget 1 icon
      (title off)
-     (origin 117 124)
+     (origin 117 119)
      (extent 114 39)
      (format button)
     )
    )
    (widget 6 detail
     (title on)
-    (origin 362 111)
+    (origin 362 106)
     (extent 192 104)
     (format buttons)
    )
   )
   (detail
-   (origin 0 67)
-   (extent 1004 664)
+   (origin 0 62)
+   (extent 933 563)
    (configuration
     (connect D10:1 D0:1
-     (Point 501 320)
-     (Point 530 320)
-     (Point 530 390)
-     (Point 584 390)
+     (Point 541 310)
+     (Point 570 310)
+     (Point 570 390)
+     (Point 614 390)
     )
     (connect D9:1 D0:2
-     (Point 501 380)
-     (Point 520 380)
-     (Point 520 400)
-     (Point 584 400)
+     (Point 541 370)
+     (Point 560 370)
+     (Point 560 400)
+     (Point 614 400)
     )
     (connect D7:1 D0:3
-     (Point 517 440)
-     (Point 530 440)
-     (Point 530 410)
-     (Point 584 410)
+     (Point 567 430)
+     (Point 580 430)
+     (Point 580 410)
+     (Point 614 410)
     )
     (connect D8:1 D0:4
-     (Point 501 490)
-     (Point 540 490)
-     (Point 540 420)
-     (Point 584 420)
+     (Point 551 480)
+     (Point 590 480)
+     (Point 590 420)
+     (Point 614 420)
     )
     (connect D0:1 D1:1
-     (Point 635 410)
-     (Point 650 410)
-     (Point 650 370)
-     (Point 660 370)
-     (Point 660 270)
-     (Point 692 270)
+     (Point 665 410)
+     (Point 680 410)
+     (Point 680 265)
+     (Point 702 265)
     )
     (connect D0:1 D2:1
-     (Point 635 410)
-     (Point 650 410)
-     (Point 650 370)
-     (Point 692 370)
+     (Point 665 410)
+     (Point 680 410)
+     (Point 680 365)
+     (Point 702 365)
     )
     (connect D0:1 D3:1
-     (Point 635 410)
-     (Point 660 410)
-     (Point 660 470)
-     (Point 692 470)
+     (Point 665 410)
+     (Point 680 410)
+     (Point 680 465)
+     (Point 702 465)
     )
     (connect D0:1 D4:1
-     (Point 635 410)
-     (Point 660 410)
-     (Point 660 470)
-     (Point 670 470)
-     (Point 670 580)
-     (Point 702 580)
+     (Point 665 410)
+     (Point 680 410)
+     (Point 680 575)
+     (Point 712 575)
     )
     (connect D6:1 D5:1
-     (Point 218 410)
-     (Point 258 410)
+     (Point 228 405)
+     (Point 240 405)
+     (Point 240 400)
+     (Point 253 400)
     )
     (connect D5:3 D7:1
-     (Point 341 410)
-     (Point 360 410)
-     (Point 360 440)
-     (Point 402 440)
+     (Point 387 400)
+     (Point 420 400)
+     (Point 420 430)
+     (Point 452 430)
     )
     (connect D5:4 D8:1
-     (Point 341 420)
-     (Point 350 420)
-     (Point 350 490)
-     (Point 418 490)
+     (Point 387 410)
+     (Point 400 410)
+     (Point 400 480)
+     (Point 468 480)
     )
     (connect D5:2 D9:1
-     (Point 341 400)
-     (Point 360 400)
-     (Point 360 380)
-     (Point 418 380)
+     (Point 387 390)
+     (Point 410 390)
+     (Point 410 370)
+     (Point 458 370)
     )
     (connect D5:1 D10:1
-     (Point 341 390)
-     (Point 350 390)
-     (Point 350 320)
-     (Point 418 320)
+     (Point 387 380)
+     (Point 400 380)
+     (Point 400 310)
+     (Point 458 310)
     )
    )
+   (stackingOrder 1 2 3 4 6 11 12 5 10 9
+     7 8 0)
   )
   (active panel)
   (active panel)
