@@ -433,7 +433,7 @@
         (icon
          (origin 582 348)
          (extent 217 64)
-         (iconImage "/usr/lib/veetest/bitmaps/notepad.icon")
+         (iconImage "notepad.icon")
         )
         (detail
          (origin 270 305)
