@@ -1,23 +1,25 @@
 #! /usr/lib/veetest/veetest -r
-(revision "A.00.01")
-(date "Sun 22/Sep/1991")
-(component 0 "Context"
+(revision "B.00.00")
+(date "Fri 23/Oct/1992")
+(component 0 "ROOTCONTEXT"
  (name "Dialog Box 3 Example")
  (interface
  )
  (implementation
-  (trigMode deg)
   (locked no)
-  (component 0 "Context"
+  (trigMode deg)
+  (nextID 4)
+  (component 0 "CONTEXT"
    (name "Press For")
    (interface
     (sequence in)
     (sequence out)
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "IfThenElse"
+    (trigMode deg)
+    (nextID 3)
+    (component 0 "IFTHENELSE"
      (name "!= 0")
      (interface
       (sequence in)
@@ -44,7 +46,7 @@
      )
      (views
       (icon
-       (origin 415 350)
+       (origin 395 355)
        (extent 46 25)
       )
       (detail
@@ -55,7 +57,7 @@
       (active icon)
      )
     )
-    (component 1 "Toggle"
+    (component 1 "TOGGLE"
      (name "Info About")
      (interface
       (sequence in)
@@ -81,12 +83,13 @@
       (component initializeAtPrerun off)
       (component initializeAtActivate off)
       (component initValue Int32
+       (name "LongInt")
        (datum 0)
       )
      )
      (views
       (icon
-       (origin 251 343)
+       (origin 231 348)
        (extent 114 39)
        (format button)
       )
@@ -98,16 +101,17 @@
       (active icon)
      )
     )
-    (component 2 "Context"
+    (component 2 "CONTEXT"
      (name "Info About This Example")
      (interface
       (sequence in)
       (sequence out)
      )
      (implementation
-      (trigMode deg)
       (locked no)
-      (component 0 "Confirm"
+      (trigMode deg)
+      (nextID 2)
+      (component 0 "CONFIRM"
        (name "DONE")
        (description 7 8
         This tiny "thread" begins running when the 
@@ -131,7 +135,7 @@
        )
        (views
         (icon
-         (origin 371 402)
+         (origin 371 407)
          (extent 58 37)
         )
         (detail
@@ -142,7 +146,7 @@
         (active icon)
        )
       )
-      (component 1 "Note"
+      (component 1 "NOTE"
        (name "Explanation")
        (interface
        )
@@ -159,7 +163,7 @@
                        seconds.
          
          EXPLANATION:  This type of dialog box is usually used for non-fatal errors.  Like
-                       dialog2.ex, this example contains an "Confirm(OK)" object and an
+                       lib/dialog.ex, this example contains an "Confirm(OK)" object and an
                        "Exit UserObject".  Notice there is another thread consisting of
                        the Delay and another "Exit UserObject".  When the Delay time is
                        reached, the "Exit UserObject" is executed, canceling all other
@@ -171,7 +175,7 @@
                        exit to occur.  Both the "Delay" and the "OK" objects, being
                        unconstrainded, execute first when the UserObject is activated.  
          
-                       The execution will either last until the user presses th OK button
+                       The execution will either last until the user presses the OK button
                        or until 5 seconds has elapsed.  The UserObject has a panel which
                        is configured to show on execute.  Notice that the message can be
                        moved to different locations once it is popped up.  This position
@@ -182,33 +186,33 @@
        )
        (views
         (icon
-         (origin 335 338)
+         (origin 335 343)
          (extent 110 25)
         )
         (detail
-         (origin 55 383)
+         (origin 25 208)
          (extent 731 295)
-         (editing enabled)
+         (editing disabled)
         )
-        (active icon)
+        (active detail)
        )
       )
       (configuration
       )
       (ShowOnExecPanel
        (origin 24 73)
-       (extent 791 440)
+       (extent 791 430)
        (panel
-        (origin 87 229)
+        (origin 67 234)
         (extent 787 402)
         (widget 0 icon
          (title off)
-         (origin 457 576)
+         (origin 437 581)
          (extent 58 37)
         )
         (widget 1 detail
          (title off)
-         (origin 98 239)
+         (origin 78 244)
          (extent 767 324)
          (editing disabled)
         )
@@ -217,16 +221,18 @@
      )
      (views
       (icon
-       (origin 372 418)
+       (origin 352 423)
        (extent 217 25)
       )
       (detail
-       (origin 17 160)
+       (origin 17 165)
        (extent 866 520)
        (configuration
        )
+       (stackingOrder 0 1)
       )
-      (active icon)
+      (active panel)
+      (active panel)
      )
     )
     (configuration
@@ -237,55 +243,57 @@
    )
    (views
     (icon
-     (origin 345 108)
+     (origin 635 368)
      (extent 110 25)
     )
     (panel
-     (origin 11 112)
+     (origin 11 107)
      (extent 319 77)
      (widget 1 icon
       (title off)
-      (origin 113 125)
+      (origin 113 120)
       (extent 114 39)
       (format button)
      )
     )
     (detail
-     (origin 10 110)
+     (origin 10 115)
      (extent 881 561)
      (configuration
       (connect D1:1 D0:1
-       (Point 367 362)
-       (Point 412 362)
+       (Point 347 367)
+       (Point 392 367)
       )
       (connect D2:0 D1:1
-       (Point 480 445)
-       (Point 480 460)
-       (Point 230 460)
-       (Point 230 362)
-       (Point 248 362)
+       (Point 460 638)
+       (Point 460 465)
+       (Point 210 465)
+       (Point 210 367)
+       (Point 228 367)
       )
       (connect D0:1 D2:0
-       (Point 463 352)
-       (Point 480 352)
-       (Point 480 415)
+       (Point 443 357)
+       (Point 460 357)
+       (Point 460 200)
       )
      )
+     (stackingOrder 0 1 2)
     )
     (active panel)
     (active panel)
    )
   )
-  (component 1 "Context"
+  (component 1 "CONTEXT"
    (name "Input Error")
    (interface
     (sequence in)
     (sequence out)
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "Delay"
+    (trigMode deg)
+    (nextID 5)
+    (component 0 "DELAY"
      (interface
       (sequence in)
       (sequence out)
@@ -303,13 +311,13 @@
       (icon
       )
       (detail
-       (origin 45 363)
+       (origin 45 358)
        (extent 130 34)
       )
       (active detail)
      )
     )
-    (component 1 "ExitContext"
+    (component 1 "EXITCONTEXT"
      (name "Exit UserObject")
      (interface
       (sequence in)
@@ -318,7 +326,7 @@
      )
      (views
       (icon
-       (origin 278 418)
+       (origin 278 413)
        (extent 145 25)
       )
       (detail
@@ -327,7 +335,7 @@
       (active icon)
      )
     )
-    (component 2 "ExitContext"
+    (component 2 "EXITCONTEXT"
      (name "Exit UserObject")
      (interface
       (sequence in)
@@ -336,7 +344,7 @@
      )
      (views
       (icon
-       (origin 128 418)
+       (origin 128 413)
        (extent 145 25)
       )
       (detail
@@ -345,7 +353,7 @@
       (active icon)
      )
     )
-    (component 3 "Confirm"
+    (component 3 "CONFIRM"
      (name " OK ")
      (interface
       (sequence in)
@@ -360,7 +368,7 @@
      )
      (views
       (icon
-       (origin 261 342)
+       (origin 261 337)
        (extent 58 37)
       )
       (detail
@@ -369,7 +377,7 @@
       (active icon)
      )
     )
-    (component 4 "Note"
+    (component 4 "NOTE"
      (name "Note Pad")
      (interface
      )
@@ -382,7 +390,7 @@
       (icon
       )
       (detail
-       (origin 48 280)
+       (origin 48 275)
        (extent 364 33)
        (editing enabled)
       )
@@ -418,25 +426,26 @@
      (extent 110 0)
     )
     (detail
-     (origin 18 237)
+     (origin 18 232)
      (extent 425 227)
      (configuration
       (connect D3:1 D1:0
-       (Point 321 360)
-       (Point 350 360)
-       (Point 350 415)
+       (Point 321 355)
+       (Point 350 355)
+       (Point 350 410)
       )
       (connect D0:1 D2:0
-       (Point 177 380)
-       (Point 200 380)
-       (Point 200 415)
+       (Point 177 375)
+       (Point 200 375)
+       (Point 200 410)
       )
      )
+     (stackingOrder 0 1 2 3 4)
     )
     (active detail)
    )
   )
-  (component 2 "Note"
+  (component 2 "NOTE"
    (name "Warranty Disclaimer")
    (interface
    )
@@ -454,14 +463,14 @@
      (extent 181 0)
     )
     (detail
-     (origin 495 111)
+     (origin 495 106)
      (extent 291 99)
      (editing disabled)
     )
     (active detail)
    )
   )
-  (component 3 "Note"
+  (component 3 "NOTE"
    (name "To Operate:")
    (interface
    )
@@ -482,7 +491,7 @@
      (iconImage "notepad.icon")
     )
     (detail
-     (origin 516 283)
+     (origin 516 278)
      (extent 288 135)
      (editing enabled)
     )
@@ -494,37 +503,38 @@
  )
  (views
   (panel
-   (origin 0 67)
+   (origin 0 62)
    (extent 839 469)
    (widget 0 panel
     (title on)
-    (origin 34 111)
+    (origin 34 106)
     (extent 319 77)
     (widget 1 icon
      (title off)
-     (origin 136 124)
+     (origin 136 119)
      (extent 114 39)
      (format button)
     )
    )
    (widget 2 detail
     (title on)
-    (origin 516 108)
+    (origin 516 103)
     (extent 291 99)
     (editing disabled)
    )
    (widget 3 detail
     (title on)
-    (origin 280 297)
+    (origin 280 292)
     (extent 283 142)
     (editing disabled)
    )
   )
   (detail
-   (origin 0 67)
+   (origin 0 62)
    (extent 887 455)
    (configuration
    )
+   (stackingOrder 1 2 3 0)
   )
   (active panel)
   (active panel)
