@@ -1,14 +1,14 @@
 #! /usr/lib/veetest/veetest -r
-(revision "A.00.01")
-(date "Sun 22/Sep/1991")
-(component 0 "Context"
+(revision "B.00.00")
+(date "Wed 09/Sep/1992")
+(component 0 "ROOTCONTEXT"
  (name "Dialog Box 4 Example")
  (interface
  )
  (implementation
-  (trigMode deg)
   (locked no)
-  (component 0 "Note"
+  (trigMode deg)
+  (component 0 "NOTE"
    (name "Warranty Disclaimer")
    (interface
    )
@@ -33,7 +33,7 @@
     (active detail)
    )
   )
-  (component 1 "TextDisplay"
+  (component 1 "TEXTDISPLAY"
    (name "Validated Input:")
    (interface
     (sequence in)
@@ -58,7 +58,7 @@
     (active detail)
    )
   )
-  (component 2 "Note"
+  (component 2 "NOTE"
    (name "To Operate:")
    (interface
    )
@@ -79,14 +79,14 @@
      (iconImage "notepad.icon")
     )
     (detail
-     (origin 706 123)
+     (origin 696 123)
      (extent 288 135)
      (editing enabled)
     )
     (active detail)
    )
   )
-  (component 3 "Context"
+  (component 3 "CONTEXT"
    (name "Validating Dialog Box")
    (interface
     (sequence in)
@@ -99,9 +99,9 @@
     )
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "RepeatUntilBreak"
+    (trigMode deg)
+    (component 0 "REPEATUNTILBREAK"
      (name "Until Break")
      (interface
       (sequence in)
@@ -126,7 +126,7 @@
       (active icon)
      )
     )
-    (component 1 "IfThenElse"
+    (component 1 "IFTHENELSE"
      (name "If/Then")
      (interface
       (sequence in)
@@ -164,16 +164,16 @@
       (active detail)
      )
     )
-    (component 2 "Context"
+    (component 2 "CONTEXT"
      (name "Input Error")
      (interface
       (sequence in)
       (sequence out)
      )
      (implementation
-      (trigMode deg)
       (locked no)
-      (component 0 "Note"
+      (trigMode deg)
+      (component 0 "NOTE"
        (name "Note Pad")
        (interface
        )
@@ -193,7 +193,7 @@
         (active detail)
        )
       )
-      (component 1 "Delay"
+      (component 1 "DELAY"
        (interface
         (sequence in)
         (sequence out)
@@ -217,7 +217,7 @@
         (active detail)
        )
       )
-      (component 2 "ExitContext"
+      (component 2 "EXITCONTEXT"
        (name "Exit UserObject")
        (interface
         (sequence in)
@@ -235,7 +235,7 @@
         (active icon)
        )
       )
-      (component 3 "ExitContext"
+      (component 3 "EXITCONTEXT"
        (name "Exit UserObject")
        (interface
         (sequence in)
@@ -253,7 +253,7 @@
         (active icon)
        )
       )
-      (component 4 "Confirm"
+      (component 4 "CONFIRM"
        (name " OK ")
        (interface
         (sequence in)
@@ -321,11 +321,12 @@
          (Point 750 815)
         )
        )
+       (stackingOrder 0 1 2 3 4)
       )
       (active icon)
      )
     )
-    (component 3 "Gate"
+    (component 3 "GATE"
      (name "Gate")
      (interface
       (sequence in)
@@ -355,7 +356,7 @@
       (active icon)
      )
     )
-    (component 4 "Confirm"
+    (component 4 "CONFIRM"
      (name " OK ")
      (interface
       (sequence in)
@@ -379,7 +380,7 @@
       (active icon)
      )
     )
-    (component 5 "Constant"
+    (component 5 "CONSTANT"
      (name "Enter a number between 1 and 10")
      (interface
       (sequence in)
@@ -391,7 +392,6 @@
      )
      (implementation
       (component value Int32
-       (name "Enter a number between 1 and 10")
        (datum 11)
       )
       (component autoTrigger off)
@@ -412,7 +412,7 @@
       (active detail)
      )
     )
-    (component 6 "ExitContext"
+    (component 6 "EXITCONTEXT"
      (name "Exit UserObject")
      (interface
       (sequence in)
@@ -430,7 +430,7 @@
       (active icon)
      )
     )
-    (component 7 "Confirm"
+    (component 7 "CONFIRM"
      (name "Cancel")
      (interface
       (sequence in)
@@ -456,7 +456,7 @@
       (active icon)
      )
     )
-    (component 8 "ExitContext"
+    (component 8 "EXITCONTEXT"
      (name "Exit UserObject")
      (interface
       (sequence in)
@@ -567,20 +567,21 @@
        (Point 663 440)
       )
      )
+     (stackingOrder 0 1 2 3 4 5 6 7 8)
     )
     (active detail)
    )
   )
-  (component 4 "Context"
+  (component 4 "CONTEXT"
    (name "Press For")
    (interface
     (sequence in)
     (sequence out)
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "IfThenElse"
+    (trigMode deg)
+    (component 0 "IFTHENELSE"
      (name "!= 0")
      (interface
       (sequence in)
@@ -618,7 +619,7 @@
       (active icon)
      )
     )
-    (component 1 "Toggle"
+    (component 1 "TOGGLE"
      (name "Info About")
      (interface
       (sequence in)
@@ -661,16 +662,16 @@
       (active icon)
      )
     )
-    (component 2 "Context"
+    (component 2 "CONTEXT"
      (name "Info About This Example")
      (interface
       (sequence in)
       (sequence out)
      )
      (implementation
-      (trigMode deg)
       (locked no)
-      (component 0 "Confirm"
+      (trigMode deg)
+      (component 0 "CONFIRM"
        (name "DONE")
        (description 7 8
         This tiny "thread" begins running when the 
@@ -705,7 +706,7 @@
         (active icon)
        )
       )
-      (component 1 "Note"
+      (component 1 "NOTE"
        (name "Explanation")
        (interface
        )
@@ -776,6 +777,7 @@
        (extent 866 520)
        (configuration
        )
+       (stackingOrder 0 1)
       )
       (active icon)
      )
@@ -822,6 +824,7 @@
        (Point 440 355)
       )
      )
+     (stackingOrder 0 1 2)
     )
     (active panel)
     (active panel)
@@ -866,13 +869,14 @@
   )
   (detail
    (origin 0 67)
-   (extent 1238 895)
+   (extent 980 561)
    (configuration
     (connect D3:1 D1:1
      (Point 688 440)
      (Point 713 440)
     )
    )
+   (stackingOrder 0 1 3 4 2)
   )
   (active panel)
   (active panel)
@@ -886,5 +890,6 @@
    (timeSpan 0.02)
    (numPoints 256)
   )
+  (delGlob yes)
  )
 )
