@@ -1,14 +1,25 @@
 #! /usr/lib/veetest/veetest -r
-(revision "A.00.00")
-(date "Thu 11/Apr/1991")
-(component 0 "Context"
+(revision "B.00.00")
+(date "Wed 09/Sep/1992")
+(component 0 "ROOTCONTEXT"
  (name "One-shot button Example")
  (interface
  )
  (implementation
-  (trigMode deg)
   (locked no)
-  (component 0 "IfThenElse"
+  (trigMode deg)
+  (component 0 "IFTHENELSE"
+   (description 9 4
+    The output of the Toggle is either 0 or 1.  This
+    object repeatedly evaluates the input and fires
+    the "Then" output only when A is non-zero.  
+    
+    Without this test, the Until Break device would
+    repeatedly cause the toggle to send a 0 or 1 to
+    it's controlled thread, executing the thread over
+    and over without regard to whether the Toggle was
+    pressed.
+   )
    (interface
     (sequence in)
     (sequence out)
@@ -33,17 +44,6 @@
     (component expr "A")
    )
    (views
-    (description 9 5
-     The output of the Toggle is either 0 or 1.  This
-     object repeatedly evaluates the input and fires
-     the "Then" output only when A is non-zero.  
-     
-     Without this test, the Until Break device would
-     repeatedly cause the toggle to send a 0 or 1 to
-     it's controlled thread, executing the thread over
-     and over without regard to whether the Toggle was
-     pressed.
-    )
     (icon
      (origin 281 228)
      (extent 78 25)
@@ -56,7 +56,7 @@
     (active detail)
    )
   )
-  (component 1 "Counter"
+  (component 1 "COUNTER"
    (interface
     (sequence in)
     (sequence out)
@@ -85,7 +85,26 @@
     (active detail)
    )
   )
-  (component 2 "Toggle"
+  (component 2 "TOGGLE"
+   (description 17 4
+    The output of the TOGGLE device is 0 when the
+    button is UP, and 1 when the button is DOWN.
+    
+    The RESET control input resets the Toggle view
+    to UP when the pin is activated.  However, it 
+    does not propagate the resulting 0 to the If/Then
+    device.  
+    
+    Autoexecute mode is enabled to allow the button to
+    operate before RUN is pressed.  However, since no
+    Autoexecute is permitted after any Thread begins
+    running, the Toggle must be driven repeatedly by
+    the Until Break iterator.  In this mode, the data
+    out (0 or 1) is repeatedly tested by the If/Then
+    to see when to execute the oneshot's thread (a
+    counter in this case.)
+    
+   )
    (interface
     (sequence in)
     (sequence out)
@@ -115,25 +134,6 @@
     )
    )
    (views
-    (description 17 5
-     The output of the TOGGLE device is 0 when the
-     button is UP, and 1 when the button is DOWN.
-     
-     The RESET control input resets the Toggle view
-     to UP when the pin is activated.  However, it 
-     does not propagate the resulting 0 to the If/Then
-     device.  
-     
-     Autoexecute mode is enabled to allow the button to
-     operate before RUN is pressed.  However, since no
-     Autoexecute is permitted after any Thread begins
-     running, the Toggle must be driven repeatedly by
-     the Until Break iterator.  In this mode, the data
-     out (0 or 1) is repeatedly tested by the If/Then
-     to see when to execute the oneshot's thread (a
-     counter in this case.)
-     
-    )
     (icon
      (origin 161 411)
      (extent 78 39)
@@ -145,7 +145,7 @@
     (active icon)
    )
   )
-  (component 3 "RepeatUntilBreak"
+  (component 3 "REPEATUNTILBREAK"
    (interface
     (sequence in)
     (sequence out)
@@ -161,7 +161,7 @@
     (icon
      (origin 25 358)
      (extent 110 64)
-     (iconImage loop.icon)
+     (iconImage "loop.icon")
     )
     (detail
     )
@@ -169,7 +169,7 @@
     (active icon)
    )
   )
-  (component 4 "RepeatUntilBreak"
+  (component 4 "REPEATUNTILBREAK"
    (interface
     (sequence in)
     (sequence out)
@@ -185,7 +185,7 @@
     (icon
      (origin 755 398)
      (extent 110 64)
-     (iconImage loop.icon)
+     (iconImage "loop.icon")
     )
     (detail
     )
@@ -193,7 +193,7 @@
     (active icon)
    )
   )
-  (component 5 "Counter"
+  (component 5 "COUNTER"
    (interface
     (sequence in)
     (sequence out)
@@ -222,7 +222,7 @@
     (active detail)
    )
   )
-  (component 6 "Note"
+  (component 6 "NOTE"
    (name "COMPLETE ONE SHOT DEVICE")
    (interface
    )
@@ -238,7 +238,7 @@
    (views
     (icon
      (extent 226 0)
-     (iconImage notepad.icon)
+     (iconImage "notepad.icon")
     )
     (detail
      (origin 10 239)
@@ -248,7 +248,7 @@
     (active detail)
    )
   )
-  (component 7 "Note"
+  (component 7 "NOTE"
    (name "A DO-NOTHING THREAD")
    (interface
    )
@@ -264,7 +264,7 @@
    (views
     (icon
      (extent 181 0)
-     (iconImage notepad.icon)
+     (iconImage "notepad.icon")
     )
     (detail
      (origin 679 241)
@@ -274,7 +274,7 @@
     (active detail)
    )
   )
-  (component 8 "Note"
+  (component 8 "NOTE"
    (name "To Operate:")
    (interface
    )
@@ -289,7 +289,7 @@
    (views
     (icon
      (extent 110 0)
-     (iconImage notepad.icon)
+     (iconImage "notepad.icon")
     )
     (detail
      (origin 348 109)
@@ -299,7 +299,7 @@
     (active detail)
    )
   )
-  (component 9 "Note"
+  (component 9 "NOTE"
    (name "Warranty Disclaimer")
    (interface
    )
@@ -323,16 +323,16 @@
     (active detail)
    )
   )
-  (component 10 "Context"
+  (component 10 "CONTEXT"
    (name "Press For")
    (interface
     (sequence in)
     (sequence out)
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "IfThenElse"
+    (trigMode deg)
+    (component 0 "IFTHENELSE"
      (name "!= 0")
      (interface
       (sequence in)
@@ -370,7 +370,7 @@
       (active icon)
      )
     )
-    (component 1 "Toggle"
+    (component 1 "TOGGLE"
      (name "Info About")
      (interface
       (sequence in)
@@ -413,7 +413,7 @@
       (active icon)
      )
     )
-    (component 2 "RepeatUntilBreak"
+    (component 2 "REPEATUNTILBREAK"
      (interface
       (sequence in)
       (sequence out)
@@ -429,7 +429,7 @@
       (icon
        (origin 155 298)
        (extent 110 64)
-       (iconImage loop.icon)
+       (iconImage "loop.icon")
       )
       (detail
       )
@@ -437,17 +437,21 @@
       (active icon)
      )
     )
-    (component 3 "Context"
+    (component 3 "CONTEXT"
      (name "Info About This Example")
      (interface
       (sequence in)
       (sequence out)
      )
      (implementation
-      (trigMode deg)
       (locked no)
-      (component 0 "Note"
+      (trigMode deg)
+      (component 0 "NOTE"
        (name "NotePad")
+       (description 2 8
+        This notepad is displayed as a Show on Execute
+        panel to present the information to the reader.
+       )
        (interface
        )
        (implementation
@@ -468,7 +472,7 @@
                       ALL start buttons are "pressed" when the user selects RUN from the titlebar
                       which is often not the desired action.  If you use the OK/Confirm button to
                       control a hosted thread, it works only after RUN has been pressed, since it
-                      has not AutoExecute mode.
+                      has no AutoExecute mode.
          
                       The solution to the problem is to use a Data -->Toggle object with a Reset
                       Control input and an If/Then device.  The Toggle has Autoexecute enabled so
@@ -491,24 +495,29 @@
         )
        )
        (views
-        (description 2 9
-         This notepad is displayed as a Show on Execute
-         panel to present the information to the reader.
-        )
         (icon
-         (origin 160 185)
+         (origin 150 235)
          (extent 78 25)
         )
         (detail
-         (origin 36 162)
+         (origin 26 212)
          (extent 848 437)
-         (editing enabled)
+         (editing disabled)
         )
         (active icon)
        )
       )
-      (component 1 "Confirm"
+      (component 1 "CONFIRM"
        (name "DONE")
+       (description 7 8
+        This tiny "thread" begins running when the 
+        enclosing UserObject is executed.  When the user
+        acknowledges the OK/DONE button, there is nothing
+        left to execute, so the thread ends.  Since there
+        are not other threads running, the User Object
+        is completed and will exit, removing the Show on
+        Execute pop-up display.
+       )
        (interface
         (sequence in)
         (sequence out)
@@ -521,17 +530,8 @@
        (implementation
        )
        (views
-        (description 7 9
-         This tiny "thread" begins running when the 
-         enclosing UserObject is executed.  When the user
-         acknowledges the OK/DONE button, there is nothing
-         left to execute, so the thread ends.  Since there
-         are not other threads running, the User Object
-         is completed and will exit, removing the Show on
-         Execute pop-up display.
-        )
         (icon
-         (origin 171 252)
+         (origin 161 302)
          (extent 58 37)
         )
         (detail
@@ -574,6 +574,7 @@
        (extent 866 520)
        (configuration
        )
+       (stackingOrder 1 0)
       )
       (active icon)
      )
@@ -626,12 +627,13 @@
        (Point 490 445)
       )
      )
+     (stackingOrder 0 1 2 3)
     )
     (active panel)
     (active panel)
    )
   )
-  (component 11 "Note"
+  (component 11 "NOTE"
    (name "SIMPLE ONE SHOT DEVICE")
    (interface
    )
@@ -647,7 +649,7 @@
    (views
     (icon
      (extent 208 0)
-     (iconImage notepad.icon)
+     (iconImage "notepad.icon")
     )
     (detail
      (origin 14 539)
@@ -657,7 +659,7 @@
     (active detail)
    )
   )
-  (component 12 "Toggle"
+  (component 12 "TOGGLE"
    (interface
     (sequence in)
     (sequence out)
@@ -698,7 +700,7 @@
     (active icon)
    )
   )
-  (component 13 "Counter"
+  (component 13 "COUNTER"
    (interface
     (sequence in)
     (sequence out)
@@ -740,7 +742,7 @@
  (views
   (detail
    (origin 0 67)
-   (extent 986 651)
+   (extent 993 648)
    (configuration
     (connect D2:1 D0:1
      (Point 241 430)
@@ -787,6 +789,8 @@
      (Point 412 700)
     )
    )
+   (stackingOrder 0 1 2 3 4 5 6 7 8 9
+     11 12 13 10)
   )
   (active detail)
   (numberFormats
@@ -799,5 +803,6 @@
    (timeSpan 0.02)
    (numPoints 256)
   )
+  (delGlob yes)
  )
 )
