@@ -1,14 +1,15 @@
 #! /usr/lib/veetest/veetest -r
-(revision "A.00.00")
-(date "Thu 11/Apr/1991")
-(component 0 "Context"
+(revision "B.00.00")
+(date "Mon 09/Nov/1992")
+(component 0 "ROOTCONTEXT"
  (name "Text Strings Example")
  (interface
  )
  (implementation
-  (trigMode rad)
   (locked no)
-  (component 0 "Note"
+  (trigMode rad)
+  (nextID 15)
+  (component 0 "NOTE"
    (name "Warranty Disclaimer")
    (interface
    )
@@ -25,14 +26,14 @@
      (extent 181 0)
     )
     (detail
-     (origin 592 119)
+     (origin 592 99)
      (extent 397 82)
      (editing disabled)
     )
     (active detail)
    )
   )
-  (component 1 "Note"
+  (component 1 "NOTE"
    (interface
    )
    (implementation
@@ -47,14 +48,14 @@
     (icon
     )
     (detail
-     (origin 351 120)
+     (origin 351 100)
      (extent 218 81)
      (editing disabled)
     )
     (active detail)
    )
   )
-  (component 2 "LiteralConstant"
+  (component 2 "LITERALCONSTANT"
    (name "Text Constant")
    (interface
     (sequence in)
@@ -74,6 +75,7 @@
     (component initializeAtPrerun off)
     (component initializeAtActivate off)
     (component initValue Text
+     (name "CString")
      (datum "")
     )
    )
@@ -83,13 +85,13 @@
      (extent 127 25)
     )
     (detail
-     (origin 30 264)
+     (origin 30 244)
      (extent 201 32)
     )
     (active detail)
    )
   )
-  (component 3 "TextDisplay"
+  (component 3 "TEXTDISPLAY"
    (interface
     (sequence in)
     (sequence out)
@@ -106,13 +108,13 @@
     (icon
     )
     (detail
-     (origin 742 249)
+     (origin 742 229)
      (extent 217 43)
     )
     (active detail)
    )
   )
-  (component 4 "TextDisplay"
+  (component 4 "TEXTDISPLAY"
    (interface
     (sequence in)
     (sequence out)
@@ -129,13 +131,13 @@
     (icon
     )
     (detail
-     (origin 743 354)
+     (origin 743 334)
      (extent 215 73)
     )
     (active detail)
    )
   )
-  (component 5 "LiteralConstant"
+  (component 5 "LITERALCONSTANT"
    (name "Text Constant")
    (interface
     (sequence in)
@@ -155,6 +157,7 @@
     (component initializeAtPrerun off)
     (component initializeAtActivate off)
     (component initValue Text
+     (name "CString")
      (datum "")
     )
    )
@@ -163,13 +166,13 @@
      (extent 127 0)
     )
     (detail
-     (origin 30 474)
+     (origin 30 454)
      (extent 201 32)
     )
     (active detail)
    )
   )
-  (component 6 "LiteralConstant"
+  (component 6 "LITERALCONSTANT"
    (name "Text Constant")
    (interface
     (sequence in)
@@ -189,6 +192,7 @@
     (component initializeAtPrerun off)
     (component initializeAtActivate off)
     (component initValue Text
+     (name "CString")
      (datum "")
     )
    )
@@ -197,13 +201,13 @@
      (extent 127 0)
     )
     (detail
-     (origin 30 364)
+     (origin 30 344)
      (extent 201 32)
     )
     (active detail)
    )
   )
-  (component 7 "Accumulator"
+  (component 7 "ACCUMULATOR"
    (interface
     (sequence in)
     (sequence out)
@@ -229,17 +233,17 @@
    )
    (views
     (icon
-     (origin 525 228)
+     (origin 525 208)
      (extent 110 25)
     )
     (detail
-     (origin 489 221)
+     (origin 779 481)
      (extent 183 38)
     )
     (active icon)
    )
   )
-  (component 8 "Collector"
+  (component 8 "COLLECTOR"
    (interface
     (sequence in)
     (sequence out)
@@ -263,6 +267,7 @@
    (implementation
     (component clearAtPrerun 1)
     (component clearAtActivate 1)
+    (component output1D YES)
    )
    (views
     (icon
@@ -270,14 +275,14 @@
      (extent 110 25)
     )
     (detail
-     (origin 561 298)
+     (origin 561 278)
      (extent 29 84)
     )
     (terminals on)
     (active detail)
    )
   )
-  (component 9 "Formula"
+  (component 9 "FORMULA"
    (interface
     (sequence in)
     (sequence out)
@@ -310,17 +315,17 @@
     (icon
      (origin 351 238)
      (extent 78 64)
-     (iconImage formula.icon)
+     (iconImage "formula.icon")
     )
     (detail
-     (origin 521 433)
+     (origin 521 413)
      (extent 89 135)
     )
     (terminals on)
     (active detail)
    )
   )
-  (component 10 "TextDisplay"
+  (component 10 "TEXTDISPLAY"
    (interface
     (sequence in)
     (sequence out)
@@ -337,13 +342,13 @@
     (icon
     )
     (detail
-     (origin 742 479)
+     (origin 742 459)
      (extent 217 43)
     )
     (active detail)
    )
   )
-  (component 11 "VectorConcatenator"
+  (component 11 "VECTORCONCATENATOR"
    (interface
     (sequence in)
     (sequence out)
@@ -377,14 +382,14 @@
      (extent 118 25)
     )
     (detail
-     (origin 489 613)
+     (origin 489 593)
      (extent 62 134)
     )
     (terminals on)
     (active detail)
    )
   )
-  (component 12 "TextDisplay"
+  (component 12 "TEXTDISPLAY"
    (name "AlphaNumeric")
    (interface
     (sequence in)
@@ -402,13 +407,13 @@
     (icon
     )
     (detail
-     (origin 654 647)
+     (origin 654 627)
      (extent 212 66)
     )
     (active detail)
    )
   )
-  (component 13 "Junction"
+  (component 13 "JUNCTION"
    (name "JCT")
    (interface
     (input 1
@@ -439,7 +444,7 @@
    )
    (views
     (icon
-     (origin 327 303)
+     (origin 327 283)
      (extent 46 34)
     )
     (detail
@@ -448,16 +453,17 @@
     (active icon)
    )
   )
-  (component 14 "Context"
+  (component 14 "CONTEXT"
    (name "Press For")
    (interface
     (sequence in)
     (sequence out)
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "Toggle"
+    (trigMode deg)
+    (nextID 3)
+    (component 0 "TOGGLE"
      (name "Info About")
      (interface
       (sequence in)
@@ -483,12 +489,13 @@
       (component initializeAtPrerun off)
       (component initializeAtActivate off)
       (component initValue Int32
+       (name "LongInt")
        (datum 0)
       )
      )
      (views
       (icon
-       (origin 203 351)
+       (origin 173 321)
        (extent 114 39)
        (format button)
       )
@@ -500,7 +507,7 @@
       (active icon)
      )
     )
-    (component 1 "IfThenElse"
+    (component 1 "IFTHENELSE"
      (name "!= 0")
      (interface
       (sequence in)
@@ -527,7 +534,7 @@
      )
      (views
       (icon
-       (origin 367 358)
+       (origin 337 328)
        (extent 46 25)
       )
       (detail
@@ -538,45 +545,56 @@
       (active icon)
      )
     )
-    (component 2 "Context"
+    (component 2 "CONTEXT"
      (name "Info About...")
      (interface
       (sequence in)
       (sequence out)
      )
      (implementation
-      (trigMode deg)
       (locked no)
-      (component 0 "Note"
+      (trigMode deg)
+      (nextID 2)
+      (component 0 "NOTE"
        (name "NotePad")
        (interface
        )
        (implementation
-        (component text 8 9
+        (component text 18 9
          PURPOSE: Illustrate several ways to combine text strings.
          
          USER INPUT REQUIRED: Press RUN to see the results displayed.
          
          EXPLANATION:  Three string constants are supplied as "One, ", "Two, ", and "Three."
                   Using the JCT to send each string in turn to the "Accumulator" allows the
-                  strings to be collected 
+                  strings to be collected into one string.  This is useful when you don't know
+         		 how many strings will be combined.  An alternate way to create the combined
+         		 string is to use a formula box to "add" the strings.  You need to have as many
+         		 inputs as you have strings to be combined.
+         
+         		 If you wish to create an array of strings instead of one string, you can use
+         		 a JCT and a collector.  The XEQ pin on the collector must be pinged when all of
+         		 the inputs have arrived.  This is done by connecting the sequence pins of the 
+         		 text constants in order and connecting the sequence out pin of the third constant
+         		 to the XEQ pin.  An alternate way to collect an array when you know the number
+         		 of strings is to use a concatenator.
          
         )
        )
        (views
         (icon
-         (origin 160 185)
+         (origin 411 408)
          (extent 78 25)
         )
         (detail
-         (origin 36 162)
+         (origin 26 202)
          (extent 848 437)
-         (editing disabled)
+         (editing enabled)
         )
         (active icon)
        )
       )
-      (component 1 "Confirm"
+      (component 1 "CONFIRM"
        (name "DONE")
        (interface
         (sequence in)
@@ -591,7 +609,7 @@
        )
        (views
         (icon
-         (origin 170 249)
+         (origin 420 469)
          (extent 58 37)
         )
         (detail
@@ -606,34 +624,35 @@
       )
       (ShowOnExecPanel
        (origin 55 78)
-       (extent 845 312)
+       (extent 866 542)
        (panel
-        (origin 40 163)
-        (extent 841 274)
-        (widget 0 detail
-         (title off)
-         (origin 53 175)
-         (extent 812 198)
-         (editing disabled)
-        )
+        (origin 29 163)
+        (extent 862 514)
         (widget 1 icon
          (title off)
-         (origin 401 384)
+         (origin 434 608)
          (extent 58 37)
         )
+        (widget 0 detail
+         (title off)
+         (origin 42 175)
+         (extent 825 420)
+         (editing disabled)
+        )
        )
       )
      )
      (views
       (icon
-       (origin 427 448)
+       (origin 397 408)
        (extent 127 25)
       )
       (detail
-       (origin 17 140)
+       (origin 17 160)
        (extent 866 520)
        (configuration
        )
+       (stackingOrder 1 0)
       )
       (active icon)
      )
@@ -646,15 +665,15 @@
    )
    (views
     (icon
-     (origin 175 368)
+     (origin 415 408)
      (extent 110 25)
     )
     (panel
-     (origin 11 122)
+     (origin 11 102)
      (extent 319 77)
      (widget 0 icon
       (title off)
-      (origin 113 135)
+      (origin 113 115)
       (extent 114 39)
       (format button)
      )
@@ -664,22 +683,25 @@
      (extent 912 591)
      (configuration
       (connect D2:0 D0:1
-       (Point 490 475)
-       (Point 490 490)
-       (Point 180 490)
-       (Point 180 370)
-       (Point 200 370)
+       (Point 460 435)
+       (Point 460 690)
+       (Point 20 690)
+       (Point 20 340)
+       (Point 170 340)
       )
       (connect D0:1 D1:1
-       (Point 319 370)
-       (Point 364 370)
+       (Point 289 340)
+       (Point 334 340)
       )
       (connect D1:1 D2:0
-       (Point 415 360)
-       (Point 490 360)
-       (Point 490 445)
+       (Point 385 330)
+       (Point 400 330)
+       (Point 400 120)
+       (Point 460 120)
+       (Point 460 405)
       )
      )
+     (stackingOrder 0 1 2)
     )
     (active panel)
     (active panel)
@@ -708,115 +730,117 @@
  )
  (views
   (detail
-   (origin 0 67)
-   (extent 980 651)
+   (origin 0 62)
+   (extent 980 643)
    (configuration
     (connect D7:1 D3:1
-     (Point 637 240)
-     (Point 670 240)
-     (Point 670 270)
-     (Point 739 270)
+     (Point 637 220)
+     (Point 670 220)
+     (Point 670 250)
+     (Point 739 250)
     )
     (connect D8:1 D4:1
-     (Point 652 340)
-     (Point 700 340)
-     (Point 700 390)
-     (Point 740 390)
+     (Point 652 320)
+     (Point 700 320)
+     (Point 700 370)
+     (Point 740 370)
     )
     (connect D6:0 D5:0
-     (Point 130 398)
-     (Point 130 441)
+     (Point 130 378)
+     (Point 130 423)
     )
     (connect D2:0 D6:0
-     (Point 130 298)
-     (Point 130 331)
+     (Point 130 278)
+     (Point 130 313)
     )
     (connect D13:1 D7:1
-     (Point 375 320)
-     (Point 490 320)
-     (Point 490 240)
-     (Point 522 240)
+     (Point 375 300)
+     (Point 490 300)
+     (Point 490 220)
+     (Point 522 220)
     )
     (connect D13:1 D8:1
-     (Point 375 320)
-     (Point 508 320)
+     (Point 375 300)
+     (Point 508 300)
     )
     (connect D5:0 D8:2
-     (Point 130 508)
-     (Point 130 530)
-     (Point 290 530)
-     (Point 290 360)
-     (Point 508 360)
+     (Point 130 488)
+     (Point 130 510)
+     (Point 290 510)
+     (Point 290 340)
+     (Point 508 340)
     )
     (connect D2:1 D9:1
-     (Point 233 280)
-     (Point 390 280)
-     (Point 390 460)
-     (Point 478 460)
+     (Point 233 260)
+     (Point 390 260)
+     (Point 390 440)
+     (Point 478 440)
     )
     (connect D6:1 D9:2
-     (Point 233 380)
-     (Point 280 380)
-     (Point 280 500)
-     (Point 478 500)
+     (Point 233 360)
+     (Point 280 360)
+     (Point 280 480)
+     (Point 478 480)
     )
     (connect D5:1 D9:3
-     (Point 233 490)
-     (Point 270 490)
-     (Point 270 540)
-     (Point 478 540)
+     (Point 233 470)
+     (Point 270 470)
+     (Point 270 520)
+     (Point 478 520)
     )
     (connect D9:1 D10:1
-     (Point 682 500)
-     (Point 739 500)
+     (Point 682 480)
+     (Point 739 480)
     )
     (connect D2:1 D11:1
-     (Point 233 280)
-     (Point 390 280)
-     (Point 390 460)
-     (Point 420 460)
-     (Point 420 640)
-     (Point 426 640)
+     (Point 233 260)
+     (Point 390 260)
+     (Point 390 440)
+     (Point 420 440)
+     (Point 420 620)
+     (Point 426 620)
     )
     (connect D6:1 D11:2
-     (Point 233 380)
-     (Point 280 380)
-     (Point 280 500)
-     (Point 410 500)
-     (Point 410 680)
-     (Point 426 680)
+     (Point 233 360)
+     (Point 280 360)
+     (Point 280 480)
+     (Point 410 480)
+     (Point 410 660)
+     (Point 426 660)
     )
     (connect D5:1 D11:3
-     (Point 233 490)
-     (Point 270 490)
-     (Point 270 540)
-     (Point 400 540)
-     (Point 400 720)
-     (Point 426 720)
+     (Point 233 470)
+     (Point 270 470)
+     (Point 270 520)
+     (Point 400 520)
+     (Point 400 700)
+     (Point 426 700)
     )
     (connect D11:1 D12:1
-     (Point 613 680)
-     (Point 651 680)
+     (Point 613 660)
+     (Point 651 660)
     )
     (connect D2:1 D13:1
-     (Point 233 280)
-     (Point 250 280)
-     (Point 250 310)
-     (Point 324 310)
+     (Point 233 260)
+     (Point 250 260)
+     (Point 250 290)
+     (Point 324 290)
     )
     (connect D6:1 D13:2
-     (Point 233 380)
-     (Point 250 380)
-     (Point 250 320)
-     (Point 324 320)
+     (Point 233 360)
+     (Point 250 360)
+     (Point 250 300)
+     (Point 324 300)
     )
     (connect D5:1 D13:3
-     (Point 233 490)
-     (Point 260 490)
-     (Point 260 330)
-     (Point 324 330)
+     (Point 233 470)
+     (Point 260 470)
+     (Point 260 310)
+     (Point 324 310)
     )
    )
+   (stackingOrder 0 1 2 3 4 5 6 8 9 10
+     11 12 13 7 14)
   )
   (active detail)
   (numberFormats
